/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import * as i0 from '@angular/core';
import { Directive, Optional, EventEmitter, Component, HostBinding, ViewChild, Input, Output, isDevMode, forwardRef, ViewChildren, ElementRef, ContentChild, InjectionToken, Inject, Injectable, ContentChildren, NgModule } from '@angular/core';
import * as i1$1 from '@progress/kendo-angular-l10n';
import { ComponentMessages, LocalizationService, L10N_PREFIX } from '@progress/kendo-angular-l10n';
import { validatePackage } from '@progress/kendo-licensing';
import { NgIf, NgTemplateOutlet, NgFor, NgSwitch, NgSwitchCase } from '@angular/common';
import { Keys, ResizeSensorComponent, isPresent, focusableSelector, guid, ResizeBatchService } from '@progress/kendo-angular-common';
import { paperPlaneIcon, chevronLeftIcon, chevronRightIcon, sparklesIcon, commentIcon, moreHorizontalIcon, thumbUpIcon, thumbDownOutlineIcon, thumbDownIcon, thumbUpOutlineIcon, copyIcon, arrowRotateCwIcon, chevronUpIcon, chevronDownIcon } from '@progress/kendo-svg-icons';
import { ButtonComponent } from '@progress/kendo-angular-buttons';
import { TextBoxComponent, TextAreaComponent, InputSeparatorComponent, TextBoxSuffixTemplateDirective, TextAreaSuffixComponent } from '@progress/kendo-angular-inputs';
import * as i1 from '@progress/kendo-angular-intl';
import { fromEvent, Subscription, Subject } from 'rxjs';
import { debounceTime } from 'rxjs/operators';
import { IconsService } from '@progress/kendo-angular-icons';
import { PopupService } from '@progress/kendo-angular-popup';
import { DialogContainerService, DialogService, WindowService, WindowContainerService } from '@progress/kendo-angular-dialog';
import { PanelBarComponent } from '@progress/kendo-angular-layout';

/**
 * Defines a template for displaying message attachments.
 *
 * To define an attachment template, nest an `<ng-template>` tag with the `kendoChatAttachmentTemplate` attribute inside the `<kendo-chat>` component.
 * The template context is set to the attachment instance.
 * For more information, refer to the article on [message attachments](slug:attachments_chat).
 *
 * @example
 * ```html
 * <kendo-chat>
 *   <ng-template kendoChatAttachmentTemplate let-attachment>
 *     <div>Attachment: {{ attachment.content }}</div>
 *   </ng-template>
 * </kendo-chat>
 * ```
 */
class AttachmentTemplateDirective {
    templateRef;
    constructor(templateRef) {
        this.templateRef = templateRef;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AttachmentTemplateDirective, deps: [{ token: i0.TemplateRef, optional: true }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: AttachmentTemplateDirective, isStandalone: true, selector: "[kendoChatAttachmentTemplate]", ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AttachmentTemplateDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[kendoChatAttachmentTemplate]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i0.TemplateRef, decorators: [{
                    type: Optional
                }] }]; } });

/**
 * Describes the arguments for the `sendMessage` event.
 */
class SendMessageEvent {
    /**
     * Represents the message that contains the metadata and user input.
     *
     * > The Chat does not automatically add the message to its data.
     * > For more information, see [Data Binding](slug:databinding_chat).
     */
    message;
    /**
     * @hidden
     */
    constructor(message) {
        this.message = message;
    }
}

const noop = () => { };
const handlers = {
    'reply': (action, sender) => {
        sender.sendMessage.emit(new SendMessageEvent({
            author: sender.user,
            text: action.value,
            timestamp: new Date()
        }));
    },
    'call': (action) => {
        window.open('tel:' + action.value);
    },
    'openUrl': (action) => {
        window.open(action.value);
    }
};
/**
 * @hidden
 */
const makeHandler = (action) => handlers[action.type] || noop;

/**
 * Defines a template for displaying Chat messages.
 *
 * To define a message template, nest an `<ng-template>` tag with the `kendoChatMessageTemplate` directive inside the `<kendo-chat>` component.
 * The template context is set to the `message` instance.
 * For more information, refer to the article on [message templates](slug:message_templates_chat).
 *
 * @example
 * ```html
 * <kendo-chat>
 *   <ng-template kendoChatMessageTemplate let-message>
 *     <div>Message: {{ message.text }}</div>
 *   </ng-template>
 * </kendo-chat>
 * ```
 */
class MessageTemplateDirective {
    templateRef;
    constructor(templateRef) {
        this.templateRef = templateRef;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: MessageTemplateDirective, deps: [{ token: i0.TemplateRef, optional: true }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: MessageTemplateDirective, isStandalone: true, selector: "[kendoChatMessageTemplate]", ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: MessageTemplateDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[kendoChatMessageTemplate]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i0.TemplateRef, decorators: [{
                    type: Optional
                }] }]; } });

/**
 * @hidden
 */
const packageMetadata = {
    name: '@progress/kendo-angular-conversational-ui',
    productName: 'Kendo UI for Angular',
    productCode: 'KENDOUIANGULAR',
    productCodes: ['KENDOUIANGULAR'],
    publishDate: 1751463370,
    version: '19.2.0',
    licensingDocsUrl: 'https://www.telerik.com/kendo-angular-ui/my-license/'
};

/**
 * Creates a message box area that overrides the default message box of the Chat component.
 *
 * To define a message box template, nest an `<ng-template>` tag with the `kendoChatMessageBoxTemplate` directive inside the `<kendo-chat>` tag.
 * For more information, see [Message Box Template](slug:message_box#toc-message-box-template).
 *
 * @example
 * ```html
 * <kendo-chat>
 *   <ng-template kendoChatMessageBoxTemplate>
 *     <input type="text" placeholder="Custom message box..." />
 *   </ng-template>
 * </kendo-chat>
 * ```
 */
class ChatMessageBoxTemplateDirective {
    templateRef;
    constructor(templateRef) {
        this.templateRef = templateRef;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ChatMessageBoxTemplateDirective, deps: [{ token: i0.TemplateRef }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: ChatMessageBoxTemplateDirective, isStandalone: true, selector: "[kendoChatMessageBoxTemplate]", ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ChatMessageBoxTemplateDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[kendoChatMessageBoxTemplate]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i0.TemplateRef }]; } });

/**
 * @hidden
 */
class MessageBoxComponent {
    borderColor = 'inherit';
    messageBoxInput;
    user;
    autoScroll;
    type;
    localization;
    messageBoxTemplate;
    sendMessage = new EventEmitter();
    /**
     * @hidden
     */
    sendIcon = paperPlaneIcon;
    /**
     * @hidden
     */
    sendClick() {
        const input = this.messageBoxInput;
        const value = input.value;
        if (!value) {
            return;
        }
        const message = {
            author: this.user,
            text: value,
            timestamp: new Date()
        };
        this.sendMessage.emit(new SendMessageEvent(message));
        input.value = null;
        input.focus();
        this.autoScroll = true;
    }
    /**
     * @hidden
     */
    inputKeydown(e) {
        if (e.keyCode === Keys.Enter) {
            this.sendClick();
        }
    }
    /**
     * @hidden
     */
    textAreaKeydown(e) {
        const isEnter = e.keyCode === Keys.Enter;
        if (!isEnter) {
            return;
        }
        const newLine = (e.metaKey || e.ctrlKey);
        const enterOnly = !(e.shiftKey || e.metaKey || e.ctrlKey);
        if (enterOnly) {
            e.preventDefault();
            this.sendClick();
        }
        if (newLine) {
            this.messageBoxInput.value += `\r\n`;
        }
    }
    /**
     * @hidden
     */
    textFor(key) {
        return this.localization.get(key);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: MessageBoxComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: MessageBoxComponent, isStandalone: true, selector: "kendo-message-box", inputs: { user: "user", autoScroll: "autoScroll", type: "type", localization: "localization", messageBoxTemplate: "messageBoxTemplate" }, outputs: { sendMessage: "sendMessage" }, host: { properties: { "style.border-color": "this.borderColor" } }, viewQueries: [{ propertyName: "messageBoxInput", first: true, predicate: ["messageBoxInput"], descendants: true }], ngImport: i0, template: `
    <ng-container *ngIf="!messageBoxTemplate">
        <kendo-textbox
            *ngIf="type === 'textbox'"
            #messageBoxInput
            class="k-message-box"
            [inputAttributes]="{
                'aria-label': textFor('messageBoxInputLabel')
            }"
            [placeholder]="textFor('messagePlaceholder')"
            (keydown)="inputKeydown($event)"
        >
            <ng-template kendoTextBoxSuffixTemplate>
                <kendo-textbox-separator></kendo-textbox-separator>
                <button
                    kendoButton
                    fillMode="flat"
                    class="k-chat-send"
                    icon="paper-plane"
                    [svgIcon]="sendIcon"
                    [tabindex]="0"
                    [attr.title]="textFor('send')"
                    (click)="sendClick()"
                >
                </button>
            </ng-template>
        </kendo-textbox>

        <kendo-textarea
            *ngIf="type === 'textarea'"
            #messageBoxInput
            class="k-message-box !k-align-items-end"
            resizable="none"
            [rows]="3"
            [inputAttributes]="{
                'aria-label': textFor('messageBoxInputLabel')
            }"
            [placeholder]="textFor('messagePlaceholder')"
            [showSuffixSeparator]="true"
            (keydown)="textAreaKeydown($event)"
        >
            <kendo-textarea-suffix>
                <button
                    kendoButton
                    fillMode="flat"
                    class="k-chat-send"
                    icon="paper-plane"
                    [svgIcon]="sendIcon"
                    [tabindex]="0"
                    [attr.title]="textFor('send')"
                    (click)="sendClick()"
                >
                </button>
            </kendo-textarea-suffix>
        </kendo-textarea>
    </ng-container>

    <ng-template *ngIf="messageBoxTemplate" [ngTemplateOutlet]="messageBoxTemplate?.templateRef"></ng-template>
`, isInline: true, dependencies: [{ kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: ButtonComponent, selector: "button[kendoButton]", inputs: ["arrowIcon", "toggleable", "togglable", "selected", "tabIndex", "imageUrl", "iconClass", "icon", "disabled", "size", "rounded", "fillMode", "themeColor", "svgIcon", "primary", "look"], outputs: ["selectedChange", "click"], exportAs: ["kendoButton"] }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: TextBoxComponent, selector: "kendo-textbox", inputs: ["focusableId", "title", "type", "disabled", "readonly", "tabindex", "value", "selectOnFocus", "showSuccessIcon", "showErrorIcon", "clearButton", "successIcon", "successSvgIcon", "errorIcon", "errorSvgIcon", "clearButtonIcon", "clearButtonSvgIcon", "size", "rounded", "fillMode", "tabIndex", "placeholder", "maxlength", "inputAttributes"], outputs: ["valueChange", "inputFocus", "inputBlur", "focus", "blur"], exportAs: ["kendoTextBox"] }, { kind: "component", type: TextAreaComponent, selector: "kendo-textarea", inputs: ["focusableId", "flow", "inputAttributes", "adornmentsOrientation", "rows", "cols", "maxlength", "tabindex", "tabIndex", "resizable", "size", "rounded", "fillMode", "showPrefixSeparator", "showSuffixSeparator"], outputs: ["focus", "blur", "valueChange"], exportAs: ["kendoTextArea"] }, { kind: "component", type: InputSeparatorComponent, selector: "kendo-input-separator, kendo-textbox-separator", inputs: ["orientation"] }, { kind: "directive", type: TextBoxSuffixTemplateDirective, selector: "[kendoTextBoxSuffixTemplate]", inputs: ["showSeparator"] }, { kind: "component", type: TextAreaSuffixComponent, selector: "kendo-textarea-suffix", inputs: ["flow", "orientation"], exportAs: ["kendoTextAreaSuffix"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: MessageBoxComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'kendo-message-box',
                    template: `
    <ng-container *ngIf="!messageBoxTemplate">
        <kendo-textbox
            *ngIf="type === 'textbox'"
            #messageBoxInput
            class="k-message-box"
            [inputAttributes]="{
                'aria-label': textFor('messageBoxInputLabel')
            }"
            [placeholder]="textFor('messagePlaceholder')"
            (keydown)="inputKeydown($event)"
        >
            <ng-template kendoTextBoxSuffixTemplate>
                <kendo-textbox-separator></kendo-textbox-separator>
                <button
                    kendoButton
                    fillMode="flat"
                    class="k-chat-send"
                    icon="paper-plane"
                    [svgIcon]="sendIcon"
                    [tabindex]="0"
                    [attr.title]="textFor('send')"
                    (click)="sendClick()"
                >
                </button>
            </ng-template>
        </kendo-textbox>

        <kendo-textarea
            *ngIf="type === 'textarea'"
            #messageBoxInput
            class="k-message-box !k-align-items-end"
            resizable="none"
            [rows]="3"
            [inputAttributes]="{
                'aria-label': textFor('messageBoxInputLabel')
            }"
            [placeholder]="textFor('messagePlaceholder')"
            [showSuffixSeparator]="true"
            (keydown)="textAreaKeydown($event)"
        >
            <kendo-textarea-suffix>
                <button
                    kendoButton
                    fillMode="flat"
                    class="k-chat-send"
                    icon="paper-plane"
                    [svgIcon]="sendIcon"
                    [tabindex]="0"
                    [attr.title]="textFor('send')"
                    (click)="sendClick()"
                >
                </button>
            </kendo-textarea-suffix>
        </kendo-textarea>
    </ng-container>

    <ng-template *ngIf="messageBoxTemplate" [ngTemplateOutlet]="messageBoxTemplate?.templateRef"></ng-template>
`,
                    standalone: true,
                    imports: [NgIf, ButtonComponent, NgTemplateOutlet, TextBoxComponent, TextAreaComponent, InputSeparatorComponent, TextBoxSuffixTemplateDirective, TextAreaSuffixComponent]
                }]
        }], propDecorators: { borderColor: [{
                type: HostBinding,
                args: ['style.border-color']
            }], messageBoxInput: [{
                type: ViewChild,
                args: ['messageBoxInput', { static: false }]
            }], user: [{
                type: Input
            }], autoScroll: [{
                type: Input
            }], type: [{
                type: Input
            }], localization: [{
                type: Input
            }], messageBoxTemplate: [{
                type: Input
            }], sendMessage: [{
                type: Output
            }] } });

/**
 * @hidden
 */
class PreventableEvent {
    prevented = false;
    /**
     * Prevents the default action for a specified event.
     * In this way, the source component suppresses
     * the built-in behavior that follows the event.
     */
    preventDefault() {
        this.prevented = true;
    }
    /**
     * Returns `true` if the event was prevented
     * by any of its subscribers.
     *
     * @returns `true` if the default action was prevented.
     * Otherwise, returns `false`.
     */
    isDefaultPrevented() {
        return this.prevented;
    }
}

/**
 * Represents the arguments for the `executeAction` event.
 *
 * The `executeAction` event fires when the user clicks a quick action button.
 * Call `preventDefault()` to suppress the built-in action handler.
 */
class ExecuteActionEvent extends PreventableEvent {
    /**
     * Represents the action to execute.
     */
    action;
    /**
     * Represents the message that contains the action.
     */
    message;
    /**
     * @hidden
     */
    constructor(action, message) {
        super();
        this.action = action;
        this.message = message;
    }
}

/**
 * @hidden
 */
const closest = (node, predicate) => {
    while (node && !predicate(node)) {
        node = node.parentNode;
    }
    return node;
};

/**
 * @hidden
 */
class ChatItem {
    selected;
}

/**
 * @hidden
 */
const isAuthor = (user, msg) => user && msg.author && user.id === msg.author.id;
const last = (arr) => arr[arr.length - 1];
const dateChanged = (curr, prev) => (curr && prev) && (prev.getDate() !== curr.getDate() ||
    prev.getMonth() !== curr.getMonth() ||
    prev.getFullYear() !== curr.getFullYear());
const addDateMarker = (acc, msg) => {
    const timestamp = msg.timestamp;
    const lastItem = last(acc);
    if (!timestamp) {
        return;
    }
    if (!lastItem || dateChanged(timestamp, lastItem.timestamp)) {
        const dateMarker = {
            type: 'date-marker',
            timestamp: timestamp,
            trackBy: timestamp.getTime()
        };
        acc.push(dateMarker);
    }
};
const groupMessages = (acc, msg, isLastMessage) => {
    const lastItem = last(acc);
    let messages;
    if (isDevMode() && !msg.author) {
        throw new Error('Author must be set for message: ' + JSON.stringify(msg));
    }
    if (msg.typing && !isLastMessage) {
        return;
    }
    if (lastItem && lastItem.type === 'message-group') {
        messages = lastItem.messages;
    }
    if (messages && isAuthor(msg.author, last(messages))) {
        messages.push(msg);
    }
    else {
        acc.push({
            type: 'message-group',
            messages: [msg],
            author: msg.author,
            timestamp: msg.timestamp,
            trackBy: msg
        });
    }
};
const groupItems = (total) => (acc, msg, index) => {
    const isLastMessage = index === total - 1;
    addDateMarker(acc, msg);
    groupMessages(acc, msg, isLastMessage);
    if (msg.attachments && msg.attachments.length > 1) {
        acc.push({
            type: 'attachment-group',
            attachments: msg.attachments,
            attachmentLayout: msg.attachmentLayout,
            timestamp: msg.timestamp,
            trackBy: msg
        });
    }
    if (msg.suggestedActions && isLastMessage) {
        acc.push({
            type: 'action-group',
            actions: msg.suggestedActions,
            timestamp: msg.timestamp,
            trackBy: msg
        });
    }
    return acc;
};
/**
 * @hidden
 */
const chatView = (messages) => messages.reduce(groupItems(messages.length), []);

/* eslint-disable @typescript-eslint/no-explicit-any */
/* eslint-disable @typescript-eslint/no-empty-function */
/**
 * @hidden
 */
class SuggestedActionsComponent extends ChatItem {
    actions;
    tabbable;
    dispatch = new EventEmitter();
    defaultClass = true;
    items;
    selectedIndex = 0;
    keyHandlers = {
        [Keys.Tab]: (e) => this.changeSelectedIndex(e),
        [Keys.Enter]: (_, action) => this.actionClick(action),
        [Keys.Space]: (_, action) => this.actionClick(action),
    };
    isSelected(index) {
        return this.selected && this.selectedIndex === index;
    }
    actionClick(action) {
        this.dispatch.next(action);
    }
    actionKeydown(e, action) {
        const handler = this.keyHandlers[e.keyCode];
        if (handler) {
            handler(e, action);
        }
    }
    focus() { }
    changeSelectedIndex(e) {
        const offset = e.shiftKey ? -1 : 1;
        const prevIndex = this.selectedIndex;
        this.selectedIndex = Math.max(0, Math.min(prevIndex + offset, this.items.length - 1));
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SuggestedActionsComponent, deps: null, target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: SuggestedActionsComponent, isStandalone: true, selector: "kendo-chat-suggested-actions", inputs: { actions: "actions", tabbable: "tabbable" }, outputs: { dispatch: "dispatch" }, host: { properties: { "class.k-quick-replies": "this.defaultClass" } }, providers: [{
                provide: ChatItem,
                useExisting: forwardRef(() => SuggestedActionsComponent)
            }], viewQueries: [{ propertyName: "items", predicate: ["item"], descendants: true }], usesInheritance: true, ngImport: i0, template: `
        <span
            #item
            *ngFor="let action of actions; index as index; first as first; last as last"
            class="k-quick-reply"
            role="button"
            [class.k-selected]="isSelected(index)"
            [class.k-focus]="isSelected(index)"
            [class.k-first]="first"
            [class.k-last]="last"
            [attr.tabindex]="0"
            (click)="actionClick(action)"
            (keydown)="actionKeydown($event, action)"
        >
        {{ action.title || action.value }}
        </span>
    `, isInline: true, dependencies: [{ kind: "directive", type: NgFor, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SuggestedActionsComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'kendo-chat-suggested-actions',
                    providers: [{
                            provide: ChatItem,
                            useExisting: forwardRef(() => SuggestedActionsComponent)
                        }],
                    template: `
        <span
            #item
            *ngFor="let action of actions; index as index; first as first; last as last"
            class="k-quick-reply"
            role="button"
            [class.k-selected]="isSelected(index)"
            [class.k-focus]="isSelected(index)"
            [class.k-first]="first"
            [class.k-last]="last"
            [attr.tabindex]="0"
            (click)="actionClick(action)"
            (keydown)="actionKeydown($event, action)"
        >
        {{ action.title || action.value }}
        </span>
    `,
                    standalone: true,
                    imports: [NgFor]
                }]
        }], propDecorators: { actions: [{
                type: Input
            }], tabbable: [{
                type: Input
            }], dispatch: [{
                type: Output
            }], defaultClass: [{
                type: HostBinding,
                args: ['class.k-quick-replies']
            }], items: [{
                type: ViewChildren,
                args: ['item']
            }] } });

// eslint-disable no-forward-ref
/**
 * @hidden
 */
class MessageComponent extends ChatItem {
    element;
    intl;
    message;
    tabbable;
    template;
    cssClass = true;
    selected;
    get tabIndex() {
        return this.tabbable ? '0' : '-1';
    }
    constructor(element, intl) {
        super();
        this.element = element;
        this.intl = intl;
    }
    formatTimeStamp(date) {
        return this.intl.formatDate(date, { datetime: 'short' });
    }
    focus() {
        this.element.nativeElement.focus();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: MessageComponent, deps: [{ token: i0.ElementRef }, { token: i1.IntlService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: MessageComponent, isStandalone: true, selector: "kendo-chat-message", inputs: { message: "message", tabbable: "tabbable", template: "template" }, host: { properties: { "class.k-message": "this.cssClass", "class.k-selected": "this.selected", "class.k-focus": "this.selected", "attr.tabIndex": "this.tabIndex" } }, providers: [{
                provide: ChatItem,
                useExisting: forwardRef(() => MessageComponent)
            }], usesInheritance: true, ngImport: i0, template: `
        <time
            [attr.aria-hidden]="!selected"
            class="k-message-time"
            *ngIf="message.timestamp"
        >
            {{ formatTimeStamp(message.timestamp) }}
        </time>

        <ng-container *ngIf="!message.typing; else typing">
            <div class="k-chat-bubble" *ngIf="template">
                <ng-container
                    *ngTemplateOutlet="template.templateRef; context: { $implicit: message };"
                >
                </ng-container>
            </div>

            <div class="k-chat-bubble" *ngIf="!template && message.text">
                {{message.text}}
            </div>
        </ng-container>

        <span
            class="k-message-status"
            *ngIf="message.status"
        >
            {{ message.status }}
        </span>

        <ng-template #typing>
            <div class="k-chat-bubble">
                <div class="k-typing-indicator">
                <span></span>
                <span></span>
                <span></span>
                </div>
            </div>
        </ng-template>
    `, isInline: true, dependencies: [{ kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: MessageComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'kendo-chat-message',
                    providers: [{
                            provide: ChatItem,
                            useExisting: forwardRef(() => MessageComponent)
                        }],
                    template: `
        <time
            [attr.aria-hidden]="!selected"
            class="k-message-time"
            *ngIf="message.timestamp"
        >
            {{ formatTimeStamp(message.timestamp) }}
        </time>

        <ng-container *ngIf="!message.typing; else typing">
            <div class="k-chat-bubble" *ngIf="template">
                <ng-container
                    *ngTemplateOutlet="template.templateRef; context: { $implicit: message };"
                >
                </ng-container>
            </div>

            <div class="k-chat-bubble" *ngIf="!template && message.text">
                {{message.text}}
            </div>
        </ng-container>

        <span
            class="k-message-status"
            *ngIf="message.status"
        >
            {{ message.status }}
        </span>

        <ng-template #typing>
            <div class="k-chat-bubble">
                <div class="k-typing-indicator">
                <span></span>
                <span></span>
                <span></span>
                </div>
            </div>
        </ng-template>
    `,
                    standalone: true,
                    imports: [NgIf, NgTemplateOutlet]
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i1.IntlService }]; }, propDecorators: { message: [{
                type: Input
            }], tabbable: [{
                type: Input
            }], template: [{
                type: Input
            }], cssClass: [{
                type: HostBinding,
                args: ['class.k-message']
            }], selected: [{
                type: HostBinding,
                args: ['class.k-selected']
            }, {
                type: HostBinding,
                args: ['class.k-focus']
            }], tabIndex: [{
                type: HostBinding,
                args: ['attr.tabIndex']
            }] } });

/**
 * @hidden
 */
class AttachmentComponent {
    set attachment(value) {
        this._attachment = value;
        this.context = {
            $implicit: this.attachment
        };
    }
    get attachment() {
        return this._attachment;
    }
    template;
    get image() {
        return this.contentType.startsWith('image/');
    }
    get unknown() {
        return !this.image;
    }
    context;
    get contentType() {
        return this.attachment.contentType || '';
    }
    _attachment;
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AttachmentComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: AttachmentComponent, isStandalone: true, selector: "kendo-chat-attachment", inputs: { attachment: "attachment", template: "template" }, ngImport: i0, template: `
        <ng-container *ngIf="template">
            <ng-container *ngTemplateOutlet="template.templateRef; context: context;">
            </ng-container>
        </ng-container>

        <div *ngIf="!template" class="k-card">
            <div class="k-card-body">
            <h5 class="k-card-title" *ngIf="attachment.title">
                {{ attachment.title }}
            </h5>
            <h6 class="k-card-subtitle" *ngIf="attachment.subtitle">
                {{ attachment.subtitle }}
            </h6>
            <img *ngIf="image" [attr.src]="attachment.content" />
            <ng-container *ngIf="unknown">
                {{ attachment.content }}
            </ng-container>
            </div>
        </div>
    `, isInline: true, dependencies: [{ kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AttachmentComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'kendo-chat-attachment',
                    template: `
        <ng-container *ngIf="template">
            <ng-container *ngTemplateOutlet="template.templateRef; context: context;">
            </ng-container>
        </ng-container>

        <div *ngIf="!template" class="k-card">
            <div class="k-card-body">
            <h5 class="k-card-title" *ngIf="attachment.title">
                {{ attachment.title }}
            </h5>
            <h6 class="k-card-subtitle" *ngIf="attachment.subtitle">
                {{ attachment.subtitle }}
            </h6>
            <img *ngIf="image" [attr.src]="attachment.content" />
            <ng-container *ngIf="unknown">
                {{ attachment.content }}
            </ng-container>
            </div>
        </div>
    `,
                    standalone: true,
                    imports: [NgIf, NgTemplateOutlet]
                }]
        }], propDecorators: { attachment: [{
                type: Input
            }], template: [{
                type: Input
            }] } });

/* eslint-disable @typescript-eslint/no-explicit-any */
// eslint-disable no-forward-ref
/**
 * @hidden
 */
class MessageAttachmentsComponent extends ChatItem {
    zone;
    localizationService;
    /**
     * @hidden
     */
    chevronLeftIcon = chevronLeftIcon;
    /**
     * @hidden
     */
    chevronRightIcon = chevronRightIcon;
    attachments;
    layout;
    tabbable;
    template;
    localization;
    get carousel() {
        return this.layout !== 'list';
    }
    deck;
    items;
    scrollPosition = 0;
    selectedIndex = 0;
    scrollSubscription;
    direction;
    get showLeftArrow() {
        return this.carousel && this.direction === 'rtl' ? this.scrollPosition > -1 : this.scrollPosition > 0;
    }
    get showRightArrow() {
        return this.carousel && this.direction === 'rtl' ? this.scrollPosition < 0 : this.scrollPosition < 1;
    }
    carouselKeyHandlers = {
        [Keys.ArrowLeft]: (e) => this.navigateTo(e, this.direction === 'rtl' ? 1 : -1),
        [Keys.ArrowRight]: (e) => this.navigateTo(e, this.direction === 'rtl' ? -1 : 1)
    };
    listKeyHandlers = {
        [Keys.ArrowUp]: (e) => this.navigateTo(e, -1),
        [Keys.ArrowDown]: (e) => this.navigateTo(e, 1)
    };
    constructor(zone, localizationService) {
        super();
        this.zone = zone;
        this.localizationService = localizationService;
        this.direction = this.localizationService.rtl ? 'rtl' : 'ltr';
    }
    ngAfterViewInit() {
        this.zone.runOutsideAngular(() => {
            const scrollDebounceTime = 100;
            this.scrollSubscription = fromEvent(this.deck.nativeElement, 'scroll')
                .pipe(debounceTime(scrollDebounceTime))
                .subscribe(() => this.onScroll());
        });
    }
    ngOnDestroy() {
        this.scrollSubscription.unsubscribe();
    }
    isSelected(index) {
        return this.selectedIndex === index;
    }
    itemKeydown(e, attachment) {
        const keyHandlers = this.layout === 'list' ?
            this.listKeyHandlers : this.carouselKeyHandlers;
        const handler = keyHandlers[e.keyCode];
        if (handler) {
            handler(e, attachment);
        }
    }
    itemClick(index) {
        this.select(index);
    }
    focus() {
        this.select(this.selectedIndex);
    }
    scrollTo(dir) {
        const el = this.deck.nativeElement;
        const scrollStep = el.scrollWidth / this.items.length;
        const max = el.scrollWidth - el.offsetWidth;
        const pos = el.scrollLeft + scrollStep * dir;
        el.scrollLeft = this.direction === 'rtl' ? Math.min(0, max, pos) : Math.max(0, Math.min(max, pos));
    }
    select(index) {
        this.selectedIndex = index;
        const item = this.items.toArray()[index];
        if (item) {
            item.nativeElement.focus();
        }
    }
    navigateTo(e, offset) {
        const prevIndex = this.selectedIndex;
        const nextIndex = Math.max(0, Math.min(prevIndex + offset, this.items.length - 1));
        if (nextIndex !== prevIndex) {
            this.select(nextIndex);
            e.preventDefault();
        }
    }
    onScroll() {
        const el = this.deck.nativeElement;
        if (el.scrollWidth === 0) {
            return;
        }
        const pos = el.scrollLeft / (el.scrollWidth - el.offsetWidth);
        if (pos !== this.scrollPosition) {
            this.zone.run(() => {
                this.scrollPosition = pos;
            });
        }
    }
    /**
     * @hidden
     */
    textFor(key) {
        return this.localization.get(key);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: MessageAttachmentsComponent, deps: [{ token: i0.NgZone }, { token: i1$1.LocalizationService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: MessageAttachmentsComponent, isStandalone: true, selector: "kendo-chat-message-attachments", inputs: { attachments: "attachments", layout: "layout", tabbable: "tabbable", template: "template", localization: "localization" }, host: { properties: { "class.k-card-deck-scrollwrap": "this.carousel" } }, providers: [{
                provide: ChatItem,
                useExisting: forwardRef(() => MessageAttachmentsComponent)
            }], viewQueries: [{ propertyName: "deck", first: true, predicate: ["deck"], descendants: true, read: ElementRef, static: true }, { propertyName: "items", predicate: ["item"], descendants: true, read: ElementRef }], usesInheritance: true, ngImport: i0, template: `
        <button
            *ngIf="showLeftArrow"
            (click)="scrollTo(-1)"
            kendoButton
            tabindex="-1"
            [attr.title]="textFor('messageAttachmentLeftArrow')"
            [svgIcon]="chevronLeftIcon"
            icon="chevron-left"
        >
        </button>
        <div
            #deck
            [class.k-card-deck]="carousel"
            [class.k-card-list]="!carousel"
        >
            <kendo-chat-attachment #item
                *ngFor="let att of attachments; index as index; first as first; last as last"
                [attachment]="att"
                [template]="template"
                [class.k-selected]="isSelected(index)"
                [class.k-focus]="isSelected(index)"
                [class.k-card-wrap]="true"
                [class.k-first]="first"
                [class.k-last]="last"
                [attr.tabindex]="tabbable && isSelected(index) ? '0' : '-1'"
                (click)="itemClick(index)"
                (keydown)="itemKeydown($event, att)"
            >
            </kendo-chat-attachment>
        </div>
        <button
            *ngIf="showRightArrow"
            (click)="scrollTo(1)"
            kendoButton
            tabindex="-1"
            [attr.title]="textFor('messageAttachmentRightArrow')"
            [svgIcon]="chevronRightIcon"
            icon="chevron-right"
        >
        </button>
    `, isInline: true, dependencies: [{ kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: ButtonComponent, selector: "button[kendoButton]", inputs: ["arrowIcon", "toggleable", "togglable", "selected", "tabIndex", "imageUrl", "iconClass", "icon", "disabled", "size", "rounded", "fillMode", "themeColor", "svgIcon", "primary", "look"], outputs: ["selectedChange", "click"], exportAs: ["kendoButton"] }, { kind: "directive", type: NgFor, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "component", type: AttachmentComponent, selector: "kendo-chat-attachment", inputs: ["attachment", "template"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: MessageAttachmentsComponent, decorators: [{
            type: Component,
            args: [{
                    providers: [{
                            provide: ChatItem,
                            useExisting: forwardRef(() => MessageAttachmentsComponent)
                        }],
                    selector: 'kendo-chat-message-attachments',
                    template: `
        <button
            *ngIf="showLeftArrow"
            (click)="scrollTo(-1)"
            kendoButton
            tabindex="-1"
            [attr.title]="textFor('messageAttachmentLeftArrow')"
            [svgIcon]="chevronLeftIcon"
            icon="chevron-left"
        >
        </button>
        <div
            #deck
            [class.k-card-deck]="carousel"
            [class.k-card-list]="!carousel"
        >
            <kendo-chat-attachment #item
                *ngFor="let att of attachments; index as index; first as first; last as last"
                [attachment]="att"
                [template]="template"
                [class.k-selected]="isSelected(index)"
                [class.k-focus]="isSelected(index)"
                [class.k-card-wrap]="true"
                [class.k-first]="first"
                [class.k-last]="last"
                [attr.tabindex]="tabbable && isSelected(index) ? '0' : '-1'"
                (click)="itemClick(index)"
                (keydown)="itemKeydown($event, att)"
            >
            </kendo-chat-attachment>
        </div>
        <button
            *ngIf="showRightArrow"
            (click)="scrollTo(1)"
            kendoButton
            tabindex="-1"
            [attr.title]="textFor('messageAttachmentRightArrow')"
            [svgIcon]="chevronRightIcon"
            icon="chevron-right"
        >
        </button>
    `,
                    standalone: true,
                    imports: [NgIf, ButtonComponent, NgFor, AttachmentComponent]
                }]
        }], ctorParameters: function () { return [{ type: i0.NgZone }, { type: i1$1.LocalizationService }]; }, propDecorators: { attachments: [{
                type: Input
            }], layout: [{
                type: Input
            }], tabbable: [{
                type: Input
            }], template: [{
                type: Input
            }], localization: [{
                type: Input
            }], carousel: [{
                type: HostBinding,
                args: ['class.k-card-deck-scrollwrap']
            }], deck: [{
                type: ViewChild,
                args: ['deck', { read: ElementRef, static: true }]
            }], items: [{
                type: ViewChildren,
                args: ['item', { read: ElementRef }]
            }] } });

/* eslint-disable @typescript-eslint/no-unused-vars */
/* eslint-disable @typescript-eslint/no-explicit-any */
/**
 * @hidden
 */
class MessageListComponent {
    element;
    intl;
    renderer;
    set messages(value) {
        const data = value || [];
        this.view = chatView(data);
        this._messages = data;
    }
    get messages() {
        return this._messages;
    }
    attachmentTemplate;
    messageTemplate;
    localization;
    user;
    executeAction = new EventEmitter();
    navigate = new EventEmitter();
    resize = new EventEmitter();
    items;
    cssClass = true;
    view = [];
    _messages;
    subs = new Subscription();
    selectedItem;
    keyActions = {
        [Keys.Home]: (_) => this.onHomeOrEndKeyDown('home'),
        [Keys.End]: (_) => this.onHomeOrEndKeyDown('end'),
        [Keys.ArrowUp]: (e) => this.navigateTo(e, -1),
        [Keys.ArrowDown]: (e) => this.navigateTo(e, 1),
        [Keys.Tab]: (e) => this.onTabKeyDown(e),
    };
    constructor(element, intl, renderer) {
        this.element = element;
        this.intl = intl;
        this.renderer = renderer;
    }
    ngOnInit() {
        const elRef = this.element.nativeElement;
        this.subs.add(this.renderer.listen(elRef, 'keydown', event => this.onKeydown(event)));
        this.subs.add(this.renderer.listen(elRef, 'focusout', event => this.onBlur(event)));
    }
    ngAfterViewInit() {
        this.selectedItem = this.items.last;
    }
    ngOnDestroy() {
        this.subs.unsubscribe();
    }
    onResize() {
        this.resize.emit();
    }
    formatTimeStamp(date) {
        return this.intl.formatDate(date, { date: 'full' });
    }
    onKeydown(e) {
        const action = this.keyActions[e.keyCode];
        if (action) {
            action(e);
        }
    }
    onBlur(args) {
        const next = args.relatedTarget || document.activeElement;
        const outside = !closest(next, (node) => node === this.element.nativeElement);
        if (outside) {
            this.select(null);
        }
    }
    isOwnMessage(msg) {
        return isAuthor(this.user, msg);
    }
    dispatchAction(action, message) {
        const args = new ExecuteActionEvent(action, message);
        this.executeAction.emit(args);
    }
    trackGroup(_index, item) {
        return item.trackBy;
    }
    select(item) {
        const prevItem = this.selectedItem;
        if (prevItem) {
            prevItem.selected = false;
        }
        if (item) {
            item.selected = true;
            this.selectedItem = item;
        }
    }
    last(items) {
        if (!items || items.length === 0) {
            return;
        }
        return items[items.length - 1];
    }
    onHomeOrEndKeyDown(key) {
        const items = this.items.toArray();
        if (key === 'home') {
            items[0].focus();
        }
        else {
            items[items.length - 1].focus();
        }
    }
    onTabKeyDown(event) {
        const item = this.items.toArray()[this.items.length - 1];
        const isLastItemQuickReply = item instanceof SuggestedActionsComponent;
        const isLastItemMessage = item instanceof MessageComponent;
        event.target.blur();
        if (isLastItemQuickReply || isLastItemMessage) {
            this.select(item);
            item.focus();
            this.navigate.emit();
        }
    }
    navigateTo(e, offset) {
        const items = this.items.toArray();
        const prevItem = this.selectedItem;
        const prevIndex = items.indexOf(prevItem);
        const nextIndex = Math.max(0, Math.min(prevIndex + offset, this.items.length - 1));
        const nextItem = items[nextIndex];
        const isNextItemQuickReply = nextItem instanceof SuggestedActionsComponent;
        if (nextItem !== prevItem) {
            if (isNextItemQuickReply) {
                nextItem.items.toArray()[0]?.nativeElement.focus();
            }
            this.select(nextItem);
            nextItem.focus();
            this.navigate.emit();
            e.preventDefault();
        }
    }
    /**
     * @hidden
     */
    textFor(key) {
        return this.localization.get(key);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: MessageListComponent, deps: [{ token: i0.ElementRef }, { token: i1.IntlService }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: MessageListComponent, isStandalone: true, selector: "kendo-chat-message-list", inputs: { messages: "messages", attachmentTemplate: "attachmentTemplate", messageTemplate: "messageTemplate", localization: "localization", user: "user" }, outputs: { executeAction: "executeAction", navigate: "navigate", resize: "resize" }, host: { properties: { "class.k-message-list-content": "this.cssClass" } }, viewQueries: [{ propertyName: "items", predicate: ChatItem, descendants: true }], ngImport: i0, template: `
        <ng-container *ngFor="let group of view; last as lastGroup; trackBy: trackGroup">
            <ng-container [ngSwitch]="group.type">
                <div
                    *ngSwitchCase="'date-marker'"
                    class="k-timestamp"
                >
                    {{ formatTimeStamp(group.timestamp) }}
                </div>
                <div
                    *ngSwitchCase="'message-group'"
                    class="k-message-group"
                    [class.k-alt]="isOwnMessage(group.messages[0])"
                    [class.k-no-avatar]="!group.author.avatarUrl"
                >
                    <p *ngIf="group.author.name" class="k-author">{{ group.author.name }}</p>
                    <div
                        *ngIf="group.author.avatarUrl"
                        class="k-avatar k-avatar-md k-avatar-solid k-avatar-solid-primary k-rounded-full"
                    >
                        <span class="k-avatar-image">
                            <img
                                [attr.src]="group.author.avatarUrl"
                                [alt]="textFor('messageAvatarAlt')"
                            />
                        </span>
                    </div>
                    <ng-container
                        *ngFor="let msg of group.messages; first as firstMessage; last as lastMessage"
                    >
                        <div
                            *ngIf="msg.user?.avatarUrl"
                            class="k-avatar k-avatar-md k-avatar-solid k-avatar-solid-primary k-rounded-full"
                        >
                            <span class="k-avatar-image">
                                <img [src]="msg.user?.avatarUrl">
                            </span>
                        </div>
                        <kendo-chat-message #message
                            [message]="msg"
                            [tabbable]="lastGroup && lastMessage"
                            [template]="messageTemplate"
                            (click)="select(message)"
                            (focus)="select(message)"
                            [class.k-only]="group.messages.length === 1"
                            [class.k-first]="group.messages.length > 1 && firstMessage"
                            [class.k-last]="group.messages.length > 1 && lastMessage"
                        >
                        </kendo-chat-message>

                        <kendo-chat-attachment
                            *ngIf="msg.attachments && msg.attachments.length === 1"
                            [attachment]="msg.attachments[0]"
                            [template]="attachmentTemplate"
                        >
                        </kendo-chat-attachment>
                    </ng-container>
                </div>

                <kendo-chat-message-attachments #attachments
                    *ngSwitchCase="'attachment-group'"
                    [attachments]="group.attachments"
                    [layout]="group.attachmentLayout"
                    [localization]="localization"
                    [tabbable]="lastGroup"
                    [template]="attachmentTemplate"
                    (click)="select(attachments)"
                    (focus)="select(attachments)"
                >
                </kendo-chat-message-attachments>

                <kendo-chat-suggested-actions #actions
                    *ngSwitchCase="'action-group'"
                    [actions]="group.actions"
                    [tabbable]="lastGroup"
                    (dispatch)="dispatchAction($event, last(group.messages))"
                    (click)="select(actions)"
                    (focus)="select(actions)"
                >
                </kendo-chat-suggested-actions>
            </ng-container>
        </ng-container>
        <kendo-resize-sensor (resize)="onResize()">
        </kendo-resize-sensor>
    `, isInline: true, dependencies: [{ kind: "directive", type: NgFor, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: NgSwitch, selector: "[ngSwitch]", inputs: ["ngSwitch"] }, { kind: "directive", type: NgSwitchCase, selector: "[ngSwitchCase]", inputs: ["ngSwitchCase"] }, { kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: MessageComponent, selector: "kendo-chat-message", inputs: ["message", "tabbable", "template"] }, { kind: "component", type: AttachmentComponent, selector: "kendo-chat-attachment", inputs: ["attachment", "template"] }, { kind: "component", type: MessageAttachmentsComponent, selector: "kendo-chat-message-attachments", inputs: ["attachments", "layout", "tabbable", "template", "localization"] }, { kind: "component", type: SuggestedActionsComponent, selector: "kendo-chat-suggested-actions", inputs: ["actions", "tabbable"], outputs: ["dispatch"] }, { kind: "component", type: ResizeSensorComponent, selector: "kendo-resize-sensor", inputs: ["rateLimit"], outputs: ["resize"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: MessageListComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'kendo-chat-message-list',
                    template: `
        <ng-container *ngFor="let group of view; last as lastGroup; trackBy: trackGroup">
            <ng-container [ngSwitch]="group.type">
                <div
                    *ngSwitchCase="'date-marker'"
                    class="k-timestamp"
                >
                    {{ formatTimeStamp(group.timestamp) }}
                </div>
                <div
                    *ngSwitchCase="'message-group'"
                    class="k-message-group"
                    [class.k-alt]="isOwnMessage(group.messages[0])"
                    [class.k-no-avatar]="!group.author.avatarUrl"
                >
                    <p *ngIf="group.author.name" class="k-author">{{ group.author.name }}</p>
                    <div
                        *ngIf="group.author.avatarUrl"
                        class="k-avatar k-avatar-md k-avatar-solid k-avatar-solid-primary k-rounded-full"
                    >
                        <span class="k-avatar-image">
                            <img
                                [attr.src]="group.author.avatarUrl"
                                [alt]="textFor('messageAvatarAlt')"
                            />
                        </span>
                    </div>
                    <ng-container
                        *ngFor="let msg of group.messages; first as firstMessage; last as lastMessage"
                    >
                        <div
                            *ngIf="msg.user?.avatarUrl"
                            class="k-avatar k-avatar-md k-avatar-solid k-avatar-solid-primary k-rounded-full"
                        >
                            <span class="k-avatar-image">
                                <img [src]="msg.user?.avatarUrl">
                            </span>
                        </div>
                        <kendo-chat-message #message
                            [message]="msg"
                            [tabbable]="lastGroup && lastMessage"
                            [template]="messageTemplate"
                            (click)="select(message)"
                            (focus)="select(message)"
                            [class.k-only]="group.messages.length === 1"
                            [class.k-first]="group.messages.length > 1 && firstMessage"
                            [class.k-last]="group.messages.length > 1 && lastMessage"
                        >
                        </kendo-chat-message>

                        <kendo-chat-attachment
                            *ngIf="msg.attachments && msg.attachments.length === 1"
                            [attachment]="msg.attachments[0]"
                            [template]="attachmentTemplate"
                        >
                        </kendo-chat-attachment>
                    </ng-container>
                </div>

                <kendo-chat-message-attachments #attachments
                    *ngSwitchCase="'attachment-group'"
                    [attachments]="group.attachments"
                    [layout]="group.attachmentLayout"
                    [localization]="localization"
                    [tabbable]="lastGroup"
                    [template]="attachmentTemplate"
                    (click)="select(attachments)"
                    (focus)="select(attachments)"
                >
                </kendo-chat-message-attachments>

                <kendo-chat-suggested-actions #actions
                    *ngSwitchCase="'action-group'"
                    [actions]="group.actions"
                    [tabbable]="lastGroup"
                    (dispatch)="dispatchAction($event, last(group.messages))"
                    (click)="select(actions)"
                    (focus)="select(actions)"
                >
                </kendo-chat-suggested-actions>
            </ng-container>
        </ng-container>
        <kendo-resize-sensor (resize)="onResize()">
        </kendo-resize-sensor>
    `,
                    standalone: true,
                    imports: [NgFor, NgSwitch, NgSwitchCase, NgIf, MessageComponent, AttachmentComponent, MessageAttachmentsComponent, SuggestedActionsComponent, ResizeSensorComponent]
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i1.IntlService }, { type: i0.Renderer2 }]; }, propDecorators: { messages: [{
                type: Input
            }], attachmentTemplate: [{
                type: Input
            }], messageTemplate: [{
                type: Input
            }], localization: [{
                type: Input
            }], user: [{
                type: Input
            }], executeAction: [{
                type: Output
            }], navigate: [{
                type: Output
            }], resize: [{
                type: Output
            }], items: [{
                type: ViewChildren,
                args: [ChatItem]
            }], cssClass: [{
                type: HostBinding,
                args: ['class.k-message-list-content']
            }] } });

// Consider scroll to be at the bottom when within this number of pixels from the container height.
const maxDelta = 2;
/**
 * @hidden
 */
class ScrollAnchorDirective {
    element;
    zone;
    renderer;
    autoScroll = true;
    autoScrollChange = new EventEmitter();
    overflowAnchor = 'none';
    scrolling = false;
    unsubscribe;
    constructor(element, zone, renderer) {
        this.element = element;
        this.zone = zone;
        this.renderer = renderer;
    }
    ngOnInit() {
        this.zone.runOutsideAngular(() => {
            this.unsubscribe = this.renderer.listen(this.element.nativeElement, 'scroll', () => this.onScroll());
        });
    }
    ngAfterViewInit() {
        this.scrollToBottom();
    }
    ngOnDestroy() {
        if (this.unsubscribe) {
            this.unsubscribe();
        }
    }
    onScroll() {
        if (this.scrolling) {
            return;
        }
        const el = this.element.nativeElement;
        const bottom = el.scrollTop + el.offsetHeight;
        const height = el.scrollHeight;
        const atBottom = height - bottom < maxDelta;
        if (this.autoScroll !== atBottom) {
            this.zone.run(() => {
                this.autoScroll = atBottom;
                this.autoScrollChange.emit(this.autoScroll);
            });
        }
    }
    scrollToBottom() {
        if (!this.autoScroll) {
            return;
        }
        const el = this.element.nativeElement;
        el.scrollTop = el.scrollHeight - el.clientHeight;
        this.scrolling = true;
        this.zone.runOutsideAngular(() => setTimeout(() => this.scrolling = false, 1000));
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ScrollAnchorDirective, deps: [{ token: i0.ElementRef }, { token: i0.NgZone }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: ScrollAnchorDirective, isStandalone: true, selector: "[kendoChatScrollAnchor]", inputs: { autoScroll: "autoScroll" }, outputs: { autoScrollChange: "autoScrollChange" }, host: { properties: { "style.overflow-anchor": "this.overflowAnchor" } }, exportAs: ["scrollAnchor"], ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ScrollAnchorDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[kendoChatScrollAnchor]',
                    exportAs: 'scrollAnchor',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.NgZone }, { type: i0.Renderer2 }]; }, propDecorators: { autoScroll: [{
                type: Input
            }], autoScrollChange: [{
                type: Output
            }], overflowAnchor: [{
                type: HostBinding,
                args: ['style.overflow-anchor']
            }] } });

/**
 * @hidden
 */
let Messages$1 = class Messages extends ComponentMessages {
    /**
     * Sets the placeholder text for the message text input.
     */
    messagePlaceholder;
    /**
     * Sets the text for the **Send** button.
     */
    send;
    /**
     * Sets the label for the message list.
     */
    messageListLabel;
    /**
     * Sets the label for the message input box.
     */
    messageBoxInputLabel;
    /**
     * Sets the text for the left arrow of the message attachments.
     */
    messageAttachmentLeftArrow;
    /**
     * Sets the text for the right arrow of the message attachments.
     */
    messageAttachmentRightArrow;
    /**
     * Sets the `alt` attribute text for the avatar image.
     */
    messageAvatarAlt;
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: Messages, deps: null, target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: Messages, selector: "kendoConversationalUIMessages", inputs: { messagePlaceholder: "messagePlaceholder", send: "send", messageListLabel: "messageListLabel", messageBoxInputLabel: "messageBoxInputLabel", messageAttachmentLeftArrow: "messageAttachmentLeftArrow", messageAttachmentRightArrow: "messageAttachmentRightArrow", messageAvatarAlt: "messageAvatarAlt" }, usesInheritance: true, ngImport: i0 });
};
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: Messages$1, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: 'kendoConversationalUIMessages'
                }]
        }], propDecorators: { messagePlaceholder: [{
                type: Input
            }], send: [{
                type: Input
            }], messageListLabel: [{
                type: Input
            }], messageBoxInputLabel: [{
                type: Input
            }], messageAttachmentLeftArrow: [{
                type: Input
            }], messageAttachmentRightArrow: [{
                type: Input
            }], messageAvatarAlt: [{
                type: Input
            }] } });

// eslint-disable no-forward-ref
/**
 * @hidden
 */
let LocalizedMessagesDirective$1 = class LocalizedMessagesDirective extends Messages$1 {
    service;
    constructor(service) {
        super();
        this.service = service;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: LocalizedMessagesDirective, deps: [{ token: i1$1.LocalizationService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: LocalizedMessagesDirective, isStandalone: true, selector: "[kendoChatLocalizedMessages]", providers: [
            {
                provide: Messages$1,
                useExisting: forwardRef(() => LocalizedMessagesDirective)
            }
        ], usesInheritance: true, ngImport: i0 });
};
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: LocalizedMessagesDirective$1, decorators: [{
            type: Directive,
            args: [{
                    providers: [
                        {
                            provide: Messages$1,
                            useExisting: forwardRef(() => LocalizedMessagesDirective$1)
                        }
                    ],
                    selector: '[kendoChatLocalizedMessages]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1$1.LocalizationService }]; } });

/**
 * Represents the [Kendo UI Chat component for Angular](slug:overview_convui).
 *
 * Provides a conversational UI for chat-based applications.
 * Supports message templates, attachments, localization, and user actions.
 *
 * @example
 * ```html
 * <kendo-chat
 *   [messages]="messages"
 *   [user]="user"
 *   (sendMessage)="onSendMessage($event)"
 *   (executeAction)="onExecuteAction($event)">
 * </kendo-chat>
 * ```
 *
 * @remarks
 * Supported children components are: {@link CustomMessagesComponent}, {@link HeroCardComponent}.
 */
class ChatComponent {
    localization;
    zone;
    /**
     * Defines the array of messages displayed in the Chat.
     * Each message can include a timestamp for unique identification.
     * For more information, refer to [ngFor - Change Tracking](link:site.data.urls.angular['ngforof']#change-propagation).
     */
    messages;
    /**
     * Specifies the [`User`](slug:api_conversational-ui_user) instance representing the local user.
     * The User ID is used to distinguish messages authored by the local user.
     */
    user;
    /**
     * Determines the type of input used in the message box.
     * Can be set to `textbox` for a single-line input or `textarea` for multi-line input
     * ([see example](slug:message_box#message-box-types)).
     * @default 'textbox'
     */
    messageBoxType = 'textbox';
    /**
     * Emits when the user sends a message by clicking the **Send** button or pressing **Enter**.
     *
     * > The message is not automatically added to the `messages` array.
     */
    sendMessage = new EventEmitter();
    /**
     * Emits when the user clicks a quick action button.
     * The Chat internally handles [known actions](slug:api_conversational-ui_actiontype) such as `reply`, `openUrl`, and `call`.
     *
     * The event is preventable&mdash;calling `preventDefault` suppresses the built-in action.
     */
    executeAction = new EventEmitter();
    get className() {
        return 'k-chat';
    }
    get dirAttr() {
        return this.direction;
    }
    attachmentTemplate;
    messageTemplate;
    messageBoxTemplate;
    messageBox;
    /**
     * @hidden
     */
    messageList;
    /**
     * @hidden
     */
    get localizationText() {
        return this.localization;
    }
    /**
     * @hidden
     */
    autoScroll = true;
    direction;
    localizationChangeSubscription;
    constructor(localization, zone) {
        this.localization = localization;
        this.zone = zone;
        validatePackage(packageMetadata);
        this.direction = localization.rtl ? 'rtl' : 'ltr';
        this.localizationChangeSubscription = localization.changes.subscribe(({ rtl }) => {
            this.direction = rtl ? 'rtl' : 'ltr';
        });
    }
    ngOnChanges() {
        this.zone.runOutsideAngular(() => setTimeout(() => {
            this.messageList.nativeElement.style.flex = '1 1 auto';
        }));
    }
    ngAfterViewInit() {
        if (!isDevMode()) {
            return;
        }
        if (!this.user) {
            throw new Error('User must be set and have a valid id.');
        }
    }
    ngOnDestroy() {
        if (this.localizationChangeSubscription) {
            this.localizationChangeSubscription.unsubscribe();
        }
    }
    /**
     * @hidden
     */
    dispatchAction(e) {
        this.executeAction.emit(e);
        if (!e.isDefaultPrevented()) {
            const handler = makeHandler(e.action);
            handler(e.action, this);
            if (!this.messageBoxTemplate) {
                this.messageBox.messageBoxInput.focus();
            }
        }
    }
    /**
     * @hidden
     */
    textFor(key) {
        return this.localization.get(key);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ChatComponent, deps: [{ token: i1$1.LocalizationService }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: ChatComponent, isStandalone: true, selector: "kendo-chat", inputs: { messages: "messages", user: "user", messageBoxType: "messageBoxType" }, outputs: { sendMessage: "sendMessage", executeAction: "executeAction" }, host: { properties: { "class": "this.className", "attr.dir": "this.dirAttr" } }, providers: [
            LocalizationService,
            {
                provide: L10N_PREFIX,
                useValue: 'kendo.chat'
            }
        ], queries: [{ propertyName: "attachmentTemplate", first: true, predicate: AttachmentTemplateDirective, descendants: true }, { propertyName: "messageTemplate", first: true, predicate: MessageTemplateDirective, descendants: true }, { propertyName: "messageBoxTemplate", first: true, predicate: ChatMessageBoxTemplateDirective, descendants: true }], viewQueries: [{ propertyName: "messageBox", first: true, predicate: ["messageBox"], descendants: true }, { propertyName: "messageList", first: true, predicate: ["messageList"], descendants: true, static: true }], usesOnChanges: true, ngImport: i0, template: `
        <ng-container kendoChatLocalizedMessages
            i18n-messagePlaceholder="kendo.chat.messagePlaceholder|The placholder text of the message text input"
            messagePlaceholder="Type a message..."

            i18n-send="kendo.chat.send|The text for the Send button"
            send="Send..."

            i18n-messageListLabel="kendo.chat.messageListLabel|The label text for the Message list"
            messageListLabel="Message list"

            i18n-messageBoxInputLabel="kendo.chat.messageBoxInputLabel|The label text for the Message input box"
            messageBoxInputLabel="Message"

            i18n-messageAttachmentLeftArrow="kendo.chat.messageAttachmentLeftArrow|The text for the left arrow of the message attachments"
            messageAttachmentLeftArrow="Previous item"

            i18n-messageAttachmentRightArrow="kendo.chat.messageAttachmentRightArrow|The text for the right arrow of the message attachments"
            messageAttachmentRightArrow="Next item"

            i18n-messageAvatarAlt="kendo.chat.messageAvatarAlt|The alt attribute text for the avatar"
            messageAvatarAlt="Avatar"
        >
        </ng-container>

        <div
            #messageList
            class="k-message-list k-avatars"
            aria-live="polite"
            role="log"
            kendoChatScrollAnchor
            [attr.aria-label]="textFor('messageListLabel')"
            #anchor="scrollAnchor"
            [(autoScroll)]="autoScroll"
        >
            <kendo-chat-message-list
                [messages]="messages"
                [messageTemplate]="messageTemplate"
                [localization]="localizationText"
                [attachmentTemplate]="attachmentTemplate"
                [user]="user"
                (executeAction)="dispatchAction($event)"
                (resize)="anchor.scrollToBottom()"
                (navigate)="this.autoScroll = false"
            >
            </kendo-chat-message-list>
        </div>
        <kendo-message-box
        #messageBox
        [messageBoxTemplate]="messageBoxTemplate"
        [type]="messageBoxType"
        [user]="user"
        [autoScroll]="autoScroll"
        [localization]="localizationText"
        (sendMessage)="sendMessage.emit($event)"
        >
        </kendo-message-box>
    `, isInline: true, dependencies: [{ kind: "directive", type: LocalizedMessagesDirective$1, selector: "[kendoChatLocalizedMessages]" }, { kind: "directive", type: ScrollAnchorDirective, selector: "[kendoChatScrollAnchor]", inputs: ["autoScroll"], outputs: ["autoScrollChange"], exportAs: ["scrollAnchor"] }, { kind: "component", type: MessageListComponent, selector: "kendo-chat-message-list", inputs: ["messages", "attachmentTemplate", "messageTemplate", "localization", "user"], outputs: ["executeAction", "navigate", "resize"] }, { kind: "component", type: MessageBoxComponent, selector: "kendo-message-box", inputs: ["user", "autoScroll", "type", "localization", "messageBoxTemplate"], outputs: ["sendMessage"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ChatComponent, decorators: [{
            type: Component,
            args: [{
                    providers: [
                        LocalizationService,
                        {
                            provide: L10N_PREFIX,
                            useValue: 'kendo.chat'
                        }
                    ],
                    selector: 'kendo-chat',
                    template: `
        <ng-container kendoChatLocalizedMessages
            i18n-messagePlaceholder="kendo.chat.messagePlaceholder|The placholder text of the message text input"
            messagePlaceholder="Type a message..."

            i18n-send="kendo.chat.send|The text for the Send button"
            send="Send..."

            i18n-messageListLabel="kendo.chat.messageListLabel|The label text for the Message list"
            messageListLabel="Message list"

            i18n-messageBoxInputLabel="kendo.chat.messageBoxInputLabel|The label text for the Message input box"
            messageBoxInputLabel="Message"

            i18n-messageAttachmentLeftArrow="kendo.chat.messageAttachmentLeftArrow|The text for the left arrow of the message attachments"
            messageAttachmentLeftArrow="Previous item"

            i18n-messageAttachmentRightArrow="kendo.chat.messageAttachmentRightArrow|The text for the right arrow of the message attachments"
            messageAttachmentRightArrow="Next item"

            i18n-messageAvatarAlt="kendo.chat.messageAvatarAlt|The alt attribute text for the avatar"
            messageAvatarAlt="Avatar"
        >
        </ng-container>

        <div
            #messageList
            class="k-message-list k-avatars"
            aria-live="polite"
            role="log"
            kendoChatScrollAnchor
            [attr.aria-label]="textFor('messageListLabel')"
            #anchor="scrollAnchor"
            [(autoScroll)]="autoScroll"
        >
            <kendo-chat-message-list
                [messages]="messages"
                [messageTemplate]="messageTemplate"
                [localization]="localizationText"
                [attachmentTemplate]="attachmentTemplate"
                [user]="user"
                (executeAction)="dispatchAction($event)"
                (resize)="anchor.scrollToBottom()"
                (navigate)="this.autoScroll = false"
            >
            </kendo-chat-message-list>
        </div>
        <kendo-message-box
        #messageBox
        [messageBoxTemplate]="messageBoxTemplate"
        [type]="messageBoxType"
        [user]="user"
        [autoScroll]="autoScroll"
        [localization]="localizationText"
        (sendMessage)="sendMessage.emit($event)"
        >
        </kendo-message-box>
    `,
                    standalone: true,
                    imports: [LocalizedMessagesDirective$1, ScrollAnchorDirective, MessageListComponent, MessageBoxComponent]
                }]
        }], ctorParameters: function () { return [{ type: i1$1.LocalizationService }, { type: i0.NgZone }]; }, propDecorators: { messages: [{
                type: Input
            }], user: [{
                type: Input
            }], messageBoxType: [{
                type: Input
            }], sendMessage: [{
                type: Output
            }], executeAction: [{
                type: Output
            }], className: [{
                type: HostBinding,
                args: ['class']
            }], dirAttr: [{
                type: HostBinding,
                args: ['attr.dir']
            }], attachmentTemplate: [{
                type: ContentChild,
                args: [AttachmentTemplateDirective, { static: false }]
            }], messageTemplate: [{
                type: ContentChild,
                args: [MessageTemplateDirective, { static: false }]
            }], messageBoxTemplate: [{
                type: ContentChild,
                args: [ChatMessageBoxTemplateDirective, { static: false }]
            }], messageBox: [{
                type: ViewChild,
                args: ['messageBox', { static: false }]
            }], messageList: [{
                type: ViewChild,
                args: ['messageList', { static: true }]
            }] } });

/**
 * @hidden
 */
const MY_TOKEN = new InjectionToken('COMMAND_TOKEN');
/**
 * @hidden
 */
const DEFAULT_SVG_ICONS = {
    prompt: sparklesIcon,
    output: commentIcon,
    command: moreHorizontalIcon
};
/**
 * @hidden
 */
const DEFAULT_ICONS = {
    prompt: 'sparkles',
    output: 'comment',
    command: 'more-horizontal'
};

/**
 * @hidden
 */
class BaseView {
    viewType;
    localization;
    hostClasses = true;
    /**
     * @hidden
     */
    template;
    constructor(viewType, localization) {
        this.viewType = viewType;
        this.localization = localization;
        if (this.viewType !== 'custom') {
            this.icon = DEFAULT_ICONS[this.viewType];
            this.svgIcon = DEFAULT_SVG_ICONS[this.viewType];
        }
    }
    /**
     * Sets the text for the Toolbar button of the current view.
     */
    set buttonText(value) {
        this._buttonText = value;
    }
    get buttonText() {
        return isPresent(this._buttonText) ?
            this._buttonText :
            this.messageFor(`${this.viewType}View`);
    }
    /**
     * Sets the font icon for the Toolbar button of the current view.
     */
    set icon(value) {
        if (isPresent(value)) {
            this._icon = value;
        }
        else {
            this.icon = DEFAULT_ICONS[this.viewType];
        }
    }
    get icon() {
        return this._icon;
    }
    /**
     * Sets the SVG icon for the Toolbar button of the current view.
     */
    set svgIcon(value) {
        if (isPresent(value)) {
            this._svgIcon = value;
        }
        else {
            this.svgIcon = DEFAULT_SVG_ICONS[this.viewType];
        }
    }
    get svgIcon() {
        return this._svgIcon;
    }
    /**
     * @hidden
     */
    messageFor(text) {
        return this.localization.get(text);
    }
    _buttonText;
    _icon;
    _svgIcon;
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: BaseView, deps: [{ token: MY_TOKEN }, { token: i1$1.LocalizationService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: BaseView, inputs: { buttonText: "buttonText", icon: "icon", svgIcon: "svgIcon" }, host: { properties: { "class.k-prompt-view": "this.hostClasses" } }, viewQueries: [{ propertyName: "template", first: true, predicate: ["content"], descendants: true, static: true }], ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: BaseView, decorators: [{
            type: Directive
        }], ctorParameters: function () { return [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [MY_TOKEN]
                }] }, { type: i1$1.LocalizationService }]; }, propDecorators: { hostClasses: [{
                type: HostBinding,
                args: ['class.k-prompt-view']
            }], template: [{
                type: ViewChild,
                args: ['content', { static: true }]
            }], buttonText: [{
                type: Input
            }], icon: [{
                type: Input
            }], svgIcon: [{
                type: Input
            }] } });

/**
 * @hidden
 */
class AIPromptService {
    aiPrompt;
    promptValue = '';
    showOutputRating = false;
    requestEvent = new Subject();
    executeEvent = new Subject();
    outputCopyEvent = new Subject();
    outputRatingChangeEvent = new Subject();
    promptCommands;
    promptOutputs;
    promptSuggestions;
    getFlattenPromptCommands(commands = this.promptCommands) {
        let newArr = [];
        commands.forEach(c => {
            if (c.hasOwnProperty('children')) {
                const childrenArr = c.children;
                newArr = newArr.concat(childrenArr);
                if (childrenArr.length > 0) {
                    this.getFlattenPromptCommands(childrenArr);
                }
            }
        });
        return newArr.concat(this.promptCommands);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AIPromptService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AIPromptService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AIPromptService, decorators: [{
            type: Injectable
        }] });

/**
 * Represents a template for additional Toolbar actions.
 * The actions appear after the Toolbar buttons for all views.
 *
 * To define the template, nest an `<ng-template>` tag
 * with the `kendoAIPromptToolbarActionsTemplate` directive inside the `<kendo-aiprompt>` tag.
 *
 * @example
 * ```html
 * <kendo-aiprompt>
 *   <ng-template kendoAIPromptToolbarActionsTemplate>
 *     <button kendoButton>Custom Action</button>
 *   </ng-template>
 * </kendo-aiprompt>
 * ```
 */
class AIPromptToolbarActionsDirective {
    templateRef;
    constructor(templateRef) {
        this.templateRef = templateRef;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AIPromptToolbarActionsDirective, deps: [{ token: i0.TemplateRef, optional: true }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: AIPromptToolbarActionsDirective, isStandalone: true, selector: "[kendoAIPromptToolbarActionsTemplate]", ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AIPromptToolbarActionsDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[kendoAIPromptToolbarActionsTemplate]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i0.TemplateRef, decorators: [{
                    type: Optional
                }] }]; } });

/**
 * @hidden
 */
class ToolbarNavigationService {
    localizationService;
    focusableElements = [];
    currentFocusedIndex = 0;
    constructor(localizationService) {
        this.localizationService = localizationService;
    }
    register(tool) {
        if (!this.focusableElements.some(el => el === tool)) {
            this.focusableElements.push(tool);
        }
    }
    unregister(tool) {
        this.currentFocusedIndex = 0;
        this.focusableElements = this.focusableElements.filter(el => el !== tool);
    }
    isActive(focusable) {
        return this.focusableElements[this.currentFocusedIndex] === focusable;
    }
    setActiveIndex(tool) {
        this.currentFocusedIndex = Math.max(this.focusableElements.indexOf(tool), 0);
    }
    move(direction) {
        let delta = direction === 'right' ? 1 : -1;
        if (this.localizationService.rtl) {
            delta = -delta;
        }
        this.currentFocusedIndex += delta;
        if (this.currentFocusedIndex < 0) {
            this.currentFocusedIndex = this.focusableElements.length - 1;
        }
        else if (this.currentFocusedIndex >= this.focusableElements.length) {
            this.currentFocusedIndex = 0;
        }
        this.focusableElements[this.currentFocusedIndex].activate();
    }
    focusFirst() {
        this.focusableElements[this.currentFocusedIndex].activate();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ToolbarNavigationService, deps: [{ token: i1$1.LocalizationService }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ToolbarNavigationService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ToolbarNavigationService, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: i1$1.LocalizationService }]; } });

/**
 * @hidden
 */
class AIPromptToolbarFocusableDirective {
    host;
    navigationService;
    renderer;
    constructor(host, navigationService, renderer) {
        this.host = host;
        this.navigationService = navigationService;
        this.renderer = renderer;
        navigationService.register(this);
    }
    get element() {
        return this.host.nativeElement;
    }
    ngAfterViewInit() {
        this.renderer.setAttribute(this.element, 'tabindex', this.navigationService.isActive(this) ? '0' : '-1');
        this.element.addEventListener('keydown', this.keyDownHandler, { capture: true });
        this.element.addEventListener('click', this.clickHandler, { capture: true });
    }
    ngOnDestroy() {
        this.navigationService.unregister(this);
        this.element.removeEventListener('keydown', this.keyDownHandler, { capture: true });
        this.element.removeEventListener('click', this.clickHandler, { capture: true });
    }
    activate() {
        this.renderer.setAttribute(this.element, 'tabindex', '0');
        this.element.focus();
    }
    keyDownHandler = (e) => {
        const targetsSelf = e.target === this.element;
        const isLeftArrow = e.keyCode === Keys.ArrowLeft;
        const isRightArrow = e.keyCode === Keys.ArrowRight;
        const isArrow = isLeftArrow || isRightArrow;
        if (!targetsSelf || !isArrow) {
            return;
        }
        this.renderer.setAttribute(this.element, 'tabindex', '-1');
        this.element.querySelectorAll(focusableSelector).forEach(el => {
            this.renderer.setAttribute(el, 'tabindex', '-1');
        });
        if (isRightArrow) {
            this.navigationService.move('right');
        }
        else if (isLeftArrow) {
            this.navigationService.move('left');
        }
    };
    clickHandler = () => {
        this.navigationService.setActiveIndex(this);
    };
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AIPromptToolbarFocusableDirective, deps: [{ token: i0.ElementRef }, { token: ToolbarNavigationService }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: AIPromptToolbarFocusableDirective, isStandalone: true, selector: "[kendoAIPromptToolbarFocusable]", ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AIPromptToolbarFocusableDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[kendoAIPromptToolbarFocusable]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: ToolbarNavigationService }, { type: i0.Renderer2 }]; } });

/**
 * @hidden
 */
class Messages extends ComponentMessages {
    /**
     * Sets the Toolbar button text for the **Prompt** view.
     */
    promptView;
    /**
     * Sets the Toolbar button text for the **Output** view.
     */
    outputView;
    /**
     * Sets the text for the **Generate** button in the **Prompt** view.
     */
    generateOutput;
    /**
     * Sets the placeholder text for the **Prompt** view text area.
     */
    promptPlaceholder;
    /**
     * Sets the text for the **Copy** button text in each **Output** view card.
     */
    copyOutput;
    /**
     * Sets the **Retry** button text in each **Output** view card.
     */
    retryGeneration;
    /**
     * Sets the title of each card in the **Output** view.
     */
    outputTitle;
    /**
     * Sets the title of each retry card in the **Output** view.
     */
    outputRetryTitle;
    /**
     * Sets the title of the **Prompt suggestions** button.
     */
    promptSuggestions;
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: Messages, deps: null, target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: Messages, inputs: { promptView: "promptView", outputView: "outputView", generateOutput: "generateOutput", promptPlaceholder: "promptPlaceholder", copyOutput: "copyOutput", retryGeneration: "retryGeneration", outputTitle: "outputTitle", outputRetryTitle: "outputRetryTitle", promptSuggestions: "promptSuggestions" }, usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: Messages, decorators: [{
            type: Directive
        }], propDecorators: { promptView: [{
                type: Input
            }], outputView: [{
                type: Input
            }], generateOutput: [{
                type: Input
            }], promptPlaceholder: [{
                type: Input
            }], copyOutput: [{
                type: Input
            }], retryGeneration: [{
                type: Input
            }], outputTitle: [{
                type: Input
            }], outputRetryTitle: [{
                type: Input
            }], promptSuggestions: [{
                type: Input
            }] } });

/**
 * @hidden
 */
class LocalizedMessagesDirective extends Messages {
    service;
    constructor(service) {
        super();
        this.service = service;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: LocalizedMessagesDirective, deps: [{ token: i1$1.LocalizationService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: LocalizedMessagesDirective, isStandalone: true, selector: "[kendoAIPromptLocalizedMessages]", providers: [
            {
                provide: Messages,
                useExisting: forwardRef(() => LocalizedMessagesDirective)
            }
        ], usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: LocalizedMessagesDirective, decorators: [{
            type: Directive,
            args: [{
                    providers: [
                        {
                            provide: Messages,
                            useExisting: forwardRef(() => LocalizedMessagesDirective)
                        }
                    ],
                    selector: '[kendoAIPromptLocalizedMessages]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1$1.LocalizationService }]; } });

/**
 * Represents the [Kendo UI AIPrompt component for Angular](slug:overview_aiprompt).
 *
 * @example
 * ```html
 * <kendo-aiprompt
 *   [promptCommands]="commands"
 *   [promptSuggestions]="suggestions"
 *   [promptOutputs]="outputs"
 *   [showOutputRating]="true"
 *   (promptRequest)="onPromptRequest($event)">
 * </kendo-aiprompt>
 * ```
 *
 * @remarks
 * Supported children components are: {@link AIPromptCustomMessagesComponent}, {@link CustomViewComponent}, {@link CommandViewComponent}, {@link PromptViewComponent}, {@link OutputViewComponent}.
 */
class AIPromptComponent {
    localization;
    service;
    navigationService;
    ngZone;
    hostClasses = true;
    get dirAttr() {
        return this.direction;
    }
    constructor(localization, service, navigationService, ngZone) {
        this.localization = localization;
        this.service = service;
        this.navigationService = navigationService;
        this.ngZone = ngZone;
        validatePackage(packageMetadata);
        this.direction = localization.rtl ? 'rtl' : 'ltr';
        this.subs.add(localization.changes.subscribe(({ rtl }) => {
            this.direction = rtl ? 'rtl' : 'ltr';
        }));
    }
    /**
     * @hidden
     */
    views;
    /**
     * @hidden
     */
    toolbarActionsTemplate;
    /**
     * The active view index of the AIPrompt component.
     */
    set activeView(idx) {
        if (this._activeView !== idx) {
            this._activeView = idx;
            this.service.promptValue && (this.service.promptValue = '');
        }
    }
    get activeView() {
        return this._activeView;
    }
    /**
     * Sets the collection of commands to render in the **Command** view.
     */
    set promptCommands(value) {
        this.service.promptCommands = value;
    }
    /**
     * Sets the collection of suggestions to render in the **Prompt** view.
     */
    set promptSuggestions(value) {
        this.service.promptSuggestions = value;
    }
    /**
     * Sets the collection of generated prompt outputs to render in the **Output** view.
     */
    set promptOutputs(value) {
        this.service.promptOutputs = value;
    }
    /**
     * Specifies if the rating buttons appear in each **Output** view card.
     * By default, the rating buttons do not appear.
     * @default false
     */
    set showOutputRating(value) {
        this.service.showOutputRating = value;
    }
    /**
     * Fires when the `activeView` property is updated.
     * Use this event for two-way binding of the `activeView` property.
     */
    activeViewChange = new EventEmitter();
    /**
     * Fires when the user clicks the **Generate** button in the **Prompt** view or the **Retry** button in the **Output** view.
     * Use the event's `isRetry` field to determine the source element.
     */
    promptRequest = new EventEmitter();
    /**
     * Fires when the user clicks a **Command** view command.
     * The event data contains the selected command.
     */
    commandExecute = new EventEmitter();
    /**
     * Fires when the user clicks a **Copy** button in any **Output** view card.
     */
    outputCopy = new EventEmitter();
    /**
     * Fires when the user clicks a rating button in any **Output** view card.
     */
    outputRatingChange = new EventEmitter();
    ngAfterViewInit() {
        this.ngZone.runOutsideAngular(() => {
            this.service.aiPrompt = this;
            this.subs.add(this.service.requestEvent.subscribe(ev => this.promptRequest.emit(ev)));
            this.subs.add(this.service.executeEvent.subscribe(ev => this.commandExecute.emit(ev)));
            this.subs.add(this.service.outputCopyEvent.subscribe(ev => this.outputCopy.emit(ev)));
            this.subs.add(this.service.outputRatingChangeEvent.subscribe(ev => this.outputRatingChange.emit(ev)));
        });
    }
    ngOnDestroy() {
        this.subs.unsubscribe();
    }
    /**
     * Focuses the first focusable element in the AIPrompt component.
     */
    focus() {
        this.navigationService.focusFirst();
    }
    subs = new Subscription();
    /**
     * @hidden
     */
    get selectedView() {
        return this.viewsArray[this.activeView];
    }
    /**
     * @hidden
     */
    sparklesIcon = sparklesIcon;
    /**
     * @hidden
     */
    outputIcon = commentIcon;
    /**
     * @hidden
     */
    get viewsArray() {
        return this.views?.toArray();
    }
    direction;
    _activeView = 0;
    /**
     * @hidden
     */
    viewChange(idx) {
        if (idx !== this.activeView) {
            this.activeView = idx;
            this.activeViewChange.emit(idx);
        }
    }
    /**
     * @hidden
     */
    messageFor(text) {
        return this.localization.get(text);
    }
    /**
     * @hidden
     */
    get viewTemplate() {
        return this.selectedView?.viewType === 'custom' ? this.selectedView?.viewTemplate : this.selectedView?.template;
    }
    /**
     * @hidden
     */
    handleGenerateOutput() {
        const value = this.service.promptValue;
        const eventArgs = {
            prompt: value,
            sender: this,
            isRetry: false
        };
        this.promptRequest.emit(eventArgs);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AIPromptComponent, deps: [{ token: i1$1.LocalizationService }, { token: AIPromptService }, { token: ToolbarNavigationService }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: AIPromptComponent, isStandalone: true, selector: "kendo-aiprompt", inputs: { activeView: "activeView", promptCommands: "promptCommands", promptSuggestions: "promptSuggestions", promptOutputs: "promptOutputs", showOutputRating: "showOutputRating" }, outputs: { activeViewChange: "activeViewChange", promptRequest: "promptRequest", commandExecute: "commandExecute", outputCopy: "outputCopy", outputRatingChange: "outputRatingChange" }, host: { properties: { "class.k-prompt": "this.hostClasses", "attr.dir": "this.dirAttr" } }, providers: [
            LocalizationService,
            AIPromptService,
            ToolbarNavigationService,
            {
                provide: L10N_PREFIX,
                useValue: 'kendo.aiprompt'
            }
        ], queries: [{ propertyName: "toolbarActionsTemplate", first: true, predicate: AIPromptToolbarActionsDirective, descendants: true }, { propertyName: "views", predicate: BaseView }], exportAs: ["kendoAIPrompt"], ngImport: i0, template: `
        <ng-container kendoAIPromptLocalizedMessages
            i18n-promptView="kendo.aiprompt.promptView|The Toolbar button text for the Prompt view."
            promptView="Ask AI"
            i18n-outputView="kendo.aiprompt.outputView|The Toolbar button text for the Output view."
            outputView="Output"
            i18n-generateOutput="kendo.aiprompt.generateOutput|The text for the Generate button in the Prompt view."
            generateOutput="Generate"
            i18n-promptPlaceholder="kendo.aiprompt.promptPlaceholder|The placeholder text for the Prompt View text area."
            promptPlaceholder="Ask or generate content with AI"
            i18n-copyOutput="kendo.aiprompt.copyOutput|The Copy button text in each Output view card."
            copyOutput="Copy"
            i18n-retryGeneration="kendo.aiprompt.retryGeneration|The Retry button text in each Output view card."
            retryGeneration="Retry"
            i18n-outputTitle="kendo.aiprompt.outputTitle|The title of each Output view card."
            outputTitle="Generated with AI"
            i18n-outputRetryTitle="kendo.aiprompt.outputRetryTitle|The title of each Output view retry card."
            outputRetryTitle="Generated with AI"
            i18n-promptSuggestions="kendo.aiprompt.promptSuggestions|The title of the Prompt suggestions button."
            promptSuggestions="Prompt suggestions">
        </ng-container>
        <div class="k-prompt-header">
            <div class="k-toolbar-flat k-toolbar k-toolbar-md"
                role="toolbar">
                <button *ngFor="let view of viewsArray; let idx = index"
                    kendoButton
                    kendoAIPromptToolbarFocusable
                    type="button"
                    fillMode="flat"
                    rounded="full"
                    themeColor="primary"
                    [svgIcon]="view.svgIcon"
                    [icon]="view.icon"
                    [selected]="idx === activeView"
                    (click)="viewChange(idx)">
                    {{view.buttonText}}
                </button>

                <ng-template *ngIf="toolbarActionsTemplate"
                    [ngTemplateOutlet]="toolbarActionsTemplate?.templateRef">
                </ng-template>
            </div>
        </div>
        <div class="k-prompt-content">
            <div class="k-prompt-view">
                <ng-container *ngTemplateOutlet="viewTemplate">
                </ng-container>
            </div>
        </div>
        <div class="k-prompt-footer" *ngIf="selectedView?.viewType === 'prompt'">
            <div class="k-actions k-actions-start k-actions-horizontal k-prompt-actions">
                <button
                    kendoButton
                    type="button"
                    themeColor="primary"
                    rounded="full"
                    [svgIcon]="sparklesIcon"
                    icon="sparkles"
                    (click)="handleGenerateOutput()">{{messageFor('generateOutput')}}</button>
            </div>
        </div>
    `, isInline: true, dependencies: [{ kind: "directive", type: LocalizedMessagesDirective, selector: "[kendoAIPromptLocalizedMessages]" }, { kind: "directive", type: NgFor, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "component", type: ButtonComponent, selector: "button[kendoButton]", inputs: ["arrowIcon", "toggleable", "togglable", "selected", "tabIndex", "imageUrl", "iconClass", "icon", "disabled", "size", "rounded", "fillMode", "themeColor", "svgIcon", "primary", "look"], outputs: ["selectedChange", "click"], exportAs: ["kendoButton"] }, { kind: "directive", type: AIPromptToolbarFocusableDirective, selector: "[kendoAIPromptToolbarFocusable]" }, { kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AIPromptComponent, decorators: [{
            type: Component,
            args: [{
                    exportAs: 'kendoAIPrompt',
                    selector: 'kendo-aiprompt',
                    providers: [
                        LocalizationService,
                        AIPromptService,
                        ToolbarNavigationService,
                        {
                            provide: L10N_PREFIX,
                            useValue: 'kendo.aiprompt'
                        }
                    ],
                    template: `
        <ng-container kendoAIPromptLocalizedMessages
            i18n-promptView="kendo.aiprompt.promptView|The Toolbar button text for the Prompt view."
            promptView="Ask AI"
            i18n-outputView="kendo.aiprompt.outputView|The Toolbar button text for the Output view."
            outputView="Output"
            i18n-generateOutput="kendo.aiprompt.generateOutput|The text for the Generate button in the Prompt view."
            generateOutput="Generate"
            i18n-promptPlaceholder="kendo.aiprompt.promptPlaceholder|The placeholder text for the Prompt View text area."
            promptPlaceholder="Ask or generate content with AI"
            i18n-copyOutput="kendo.aiprompt.copyOutput|The Copy button text in each Output view card."
            copyOutput="Copy"
            i18n-retryGeneration="kendo.aiprompt.retryGeneration|The Retry button text in each Output view card."
            retryGeneration="Retry"
            i18n-outputTitle="kendo.aiprompt.outputTitle|The title of each Output view card."
            outputTitle="Generated with AI"
            i18n-outputRetryTitle="kendo.aiprompt.outputRetryTitle|The title of each Output view retry card."
            outputRetryTitle="Generated with AI"
            i18n-promptSuggestions="kendo.aiprompt.promptSuggestions|The title of the Prompt suggestions button."
            promptSuggestions="Prompt suggestions">
        </ng-container>
        <div class="k-prompt-header">
            <div class="k-toolbar-flat k-toolbar k-toolbar-md"
                role="toolbar">
                <button *ngFor="let view of viewsArray; let idx = index"
                    kendoButton
                    kendoAIPromptToolbarFocusable
                    type="button"
                    fillMode="flat"
                    rounded="full"
                    themeColor="primary"
                    [svgIcon]="view.svgIcon"
                    [icon]="view.icon"
                    [selected]="idx === activeView"
                    (click)="viewChange(idx)">
                    {{view.buttonText}}
                </button>

                <ng-template *ngIf="toolbarActionsTemplate"
                    [ngTemplateOutlet]="toolbarActionsTemplate?.templateRef">
                </ng-template>
            </div>
        </div>
        <div class="k-prompt-content">
            <div class="k-prompt-view">
                <ng-container *ngTemplateOutlet="viewTemplate">
                </ng-container>
            </div>
        </div>
        <div class="k-prompt-footer" *ngIf="selectedView?.viewType === 'prompt'">
            <div class="k-actions k-actions-start k-actions-horizontal k-prompt-actions">
                <button
                    kendoButton
                    type="button"
                    themeColor="primary"
                    rounded="full"
                    [svgIcon]="sparklesIcon"
                    icon="sparkles"
                    (click)="handleGenerateOutput()">{{messageFor('generateOutput')}}</button>
            </div>
        </div>
    `,
                    standalone: true,
                    imports: [LocalizedMessagesDirective, NgFor, ButtonComponent, AIPromptToolbarFocusableDirective, NgIf, NgTemplateOutlet]
                }]
        }], ctorParameters: function () { return [{ type: i1$1.LocalizationService }, { type: AIPromptService }, { type: ToolbarNavigationService }, { type: i0.NgZone }]; }, propDecorators: { hostClasses: [{
                type: HostBinding,
                args: ['class.k-prompt']
            }], dirAttr: [{
                type: HostBinding,
                args: ['attr.dir']
            }], views: [{
                type: ContentChildren,
                args: [BaseView]
            }], toolbarActionsTemplate: [{
                type: ContentChild,
                args: [AIPromptToolbarActionsDirective]
            }], activeView: [{
                type: Input
            }], promptCommands: [{
                type: Input
            }], promptSuggestions: [{
                type: Input
            }], promptOutputs: [{
                type: Input
            }], showOutputRating: [{
                type: Input
            }], activeViewChange: [{
                type: Output
            }], promptRequest: [{
                type: Output
            }], commandExecute: [{
                type: Output
            }], outputCopy: [{
                type: Output
            }], outputRatingChange: [{
                type: Output
            }] } });

/**
 * Represents the component that renders the **Command** view of the AIPrompt.
 *
 * @example
 * ```html
 * <kendo-aiprompt-command-view
 *      buttonText="My command view">
 * </kendo-aiprompt-command-view>
 * ```
 */
class CommandViewComponent extends BaseView {
    service;
    constructor(localization, service) {
        super('command', localization);
        this.service = service;
    }
    /**
     * @hidden
     */
    panelBarItems = [];
    ngOnInit() {
        if (this.service.promptCommands) {
            this.panelBarItems = this.getPanelBarItems(this.service.promptCommands);
        }
    }
    /**
     * @hidden
     */
    itemClickHandler(ev) {
        if (ev.item.children) {
            return;
        }
        const selectedCommand = this.service.getFlattenPromptCommands().find(c => c.id == ev.item.id);
        if (selectedCommand) {
            const eventArgs = {
                command: selectedCommand,
                sender: this.service.aiPrompt,
                isRetry: false
            };
            this.service.executeEvent.next(eventArgs);
        }
    }
    getPanelBarItems(commands) {
        return commands.map(c => ({
            title: c.text,
            id: c.id,
            icon: c.icon,
            svgIcon: c.svgIcon,
            children: c.children ? this.getPanelBarItems(c.children) : null
        }));
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CommandViewComponent, deps: [{ token: i1$1.LocalizationService }, { token: AIPromptService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: CommandViewComponent, isStandalone: true, selector: "kendo-aiprompt-command-view", providers: [{
                provide: BaseView,
                useExisting: forwardRef(() => CommandViewComponent)
            }], usesInheritance: true, ngImport: i0, template: `
        <ng-template #content>
            <kendo-panelbar
                [items]="panelBarItems"
                [animate]="false"
                [selectable]="false"
                (itemClick)="itemClickHandler($event)"
            ></kendo-panelbar>
        </ng-template>
    `, isInline: true, dependencies: [{ kind: "component", type: PanelBarComponent, selector: "kendo-panelbar", inputs: ["expandMode", "selectable", "animate", "height", "keepItemContent", "items"], outputs: ["stateChange", "select", "expand", "collapse", "itemClick"], exportAs: ["kendoPanelbar"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CommandViewComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'kendo-aiprompt-command-view',
                    providers: [{
                            provide: BaseView,
                            useExisting: forwardRef(() => CommandViewComponent)
                        }],
                    template: `
        <ng-template #content>
            <kendo-panelbar
                [items]="panelBarItems"
                [animate]="false"
                [selectable]="false"
                (itemClick)="itemClickHandler($event)"
            ></kendo-panelbar>
        </ng-template>
    `,
                    standalone: true,
                    imports: [PanelBarComponent]
                }]
        }], ctorParameters: function () { return [{ type: i1$1.LocalizationService }, { type: AIPromptService }]; } });

/**
 * Represents the custom messages component of the AIPrompt.
 *
 * Use this component to override default messages for the AIPrompt
 * ([see example](slug:globalization_chat#custom-messages)).
 *
 * @example
 * ```html
 * <kendo-aiprompt-messages
 *   promptView="My prompt view"
 *   outputView="My output view">
 * </kendo-aiprompt-messages>
 * ```
 */
class AIPromptCustomMessagesComponent extends Messages {
    service;
    constructor(service) {
        super();
        this.service = service;
    }
    get override() {
        return true;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AIPromptCustomMessagesComponent, deps: [{ token: i1$1.LocalizationService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: AIPromptCustomMessagesComponent, isStandalone: true, selector: "kendo-aiprompt-messages", providers: [
            {
                provide: Messages,
                useExisting: forwardRef(() => AIPromptCustomMessagesComponent)
            }
        ], usesInheritance: true, ngImport: i0, template: ``, isInline: true });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AIPromptCustomMessagesComponent, decorators: [{
            type: Component,
            args: [{
                    providers: [
                        {
                            provide: Messages,
                            useExisting: forwardRef(() => AIPromptCustomMessagesComponent)
                        }
                    ],
                    selector: 'kendo-aiprompt-messages',
                    template: ``,
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1$1.LocalizationService }]; } });

/**
 * Represents the component that renders a **Custom** view in the AIPrompt.
 *
 * @example
 * ```html
 * <kendo-aiprompt-custom-view [viewTemplate]="customTemplate">
 * </kendo-aiprompt-custom-view>
 *
 * <ng-template #customTemplate>
 *   <div>Custom content here</div>
 * </ng-template>
 * ```
 */
class CustomViewComponent extends BaseView {
    constructor(localization) {
        super('custom', localization);
    }
    /**
     * Sets the content of the Custom view as a template reference.
     */
    viewTemplate;
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CustomViewComponent, deps: [{ token: i1$1.LocalizationService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: CustomViewComponent, isStandalone: true, selector: "kendo-aiprompt-custom-view", inputs: { viewTemplate: "viewTemplate" }, providers: [{
                provide: BaseView,
                useExisting: forwardRef(() => CustomViewComponent)
            }], usesInheritance: true, ngImport: i0, template: ``, isInline: true });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CustomViewComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'kendo-aiprompt-custom-view',
                    providers: [{
                            provide: BaseView,
                            useExisting: forwardRef(() => CustomViewComponent)
                        }],
                    template: ``,
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1$1.LocalizationService }]; }, propDecorators: { viewTemplate: [{
                type: Input
            }] } });

/**
 * @hidden
 */
class AIPromptOutputCardComponent {
    localization;
    service;
    hostClass = true;
    listItemRole = 'listitem';
    tabIndex = 0;
    get ariaDescribedBy() {
        return this.titleId;
    }
    ariaKeyShortcuts = 'Enter';
    promptOutput;
    constructor(localization, service) {
        this.localization = localization;
        this.service = service;
    }
    ngOnInit() {
        if (this.promptOutput?.rating === 'positive') {
            this.positiveRatingIcon = thumbUpIcon;
            this.negativeRatingIcon = thumbDownOutlineIcon;
        }
        else if (this.promptOutput?.rating === 'negative') {
            this.negativeRatingIcon = thumbDownIcon;
            this.positiveRatingIcon = thumbUpOutlineIcon;
        }
    }
    copyIcon = copyIcon;
    retryIcon = arrowRotateCwIcon;
    positiveRatingIcon = thumbUpOutlineIcon;
    negativeRatingIcon = thumbDownOutlineIcon;
    titleId = `k-output-card-${guid()}`;
    messageFor(text) {
        return this.localization.get(text);
    }
    get showRating() {
        return this.service.showOutputRating;
    }
    get outputTitle() {
        if (isPresent(this.promptOutput.title)) {
            return this.promptOutput.title;
        }
        else {
            const titleMessage = this.promptOutput.isRetry ? 'outputRetryTitle' : 'outputTitle';
            return this.messageFor(titleMessage);
        }
    }
    handleRetry() {
        if (this.promptOutput.commandId) {
            const eventArgs = {
                command: this.service.getFlattenPromptCommands().find(c => c.id === this.promptOutput.commandId),
                sender: this.service.aiPrompt,
                isRetry: true
            };
            this.service.executeEvent.next(eventArgs);
        }
        else {
            const eventArgs = {
                prompt: this.promptOutput.prompt,
                sender: this.service.aiPrompt,
                isRetry: true
            };
            this.service.requestEvent.next(eventArgs);
        }
    }
    handleCopy() {
        navigator.clipboard.writeText(this.promptOutput.output);
        this.service.outputCopyEvent.next(this.promptOutput);
    }
    handleRating(ratingType) {
        const eventArgs = {
            promptOutput: this.promptOutput,
            rating: ratingType
        };
        this.service.outputRatingChangeEvent.next(eventArgs);
        if (ratingType === 'positive') {
            this.positiveRatingIcon = thumbUpIcon;
            this.negativeRatingIcon = thumbDownOutlineIcon;
        }
        else {
            this.negativeRatingIcon = thumbDownIcon;
            this.positiveRatingIcon = thumbUpOutlineIcon;
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AIPromptOutputCardComponent, deps: [{ token: i1$1.LocalizationService }, { token: AIPromptService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: AIPromptOutputCardComponent, isStandalone: true, selector: "[kendoAIPromptOutputCard]", inputs: { promptOutput: "promptOutput" }, host: { properties: { "class.k-card": "this.hostClass", "attr.role": "this.listItemRole", "attr.tabindex": "this.tabIndex", "attr.aria-describedby": "this.ariaDescribedBy", "attr.aria-keyshortcuts": "this.ariaKeyShortcuts" } }, ngImport: i0, template: `
        <div class="k-card-header">
            <div
                class="k-card-title"
                [attr.id]="titleId">{{outputTitle}}
            </div>
            <div class="k-card-subtitle">{{promptOutput.prompt}}</div>
        </div>
        <div class="k-card-body">
            <p>{{promptOutput.output}}</p>
        </div>
        <div class="k-actions k-actions-start k-actions-horizontal k-card-actions">
            <button kendoButton
                fillMode="flat"
                themeColor="primary"
                rounded="full"
                icon="copy"
                [svgIcon]="copyIcon"
                (click)="handleCopy()"
            >{{messageFor('copyOutput')}}</button>
            <button kendoButton
                fillMode="flat"
                rounded="full"
                icon="arrow-rotate-cw"
                [svgIcon]="retryIcon"
                (click)="handleRetry()"
            >{{messageFor('retryGeneration')}}</button>
            <ng-container *ngIf="showRating">
                <span class="k-spacer"></span>
                <button kendoButton
                    fillMode="flat"
                    icon="thumb-up-outline"
                    [svgIcon]="positiveRatingIcon"
                    (click)="handleRating('positive')">
                </button>
                <button kendoButton
                    fillMode="flat"
                    icon="thumb-down-outline"
                    [svgIcon]="negativeRatingIcon"
                    (click)="handleRating('negative')">
                </button>
            </ng-container>
        </div>
    `, isInline: true, dependencies: [{ kind: "component", type: ButtonComponent, selector: "button[kendoButton]", inputs: ["arrowIcon", "toggleable", "togglable", "selected", "tabIndex", "imageUrl", "iconClass", "icon", "disabled", "size", "rounded", "fillMode", "themeColor", "svgIcon", "primary", "look"], outputs: ["selectedChange", "click"], exportAs: ["kendoButton"] }, { kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AIPromptOutputCardComponent, decorators: [{
            type: Component,
            args: [{
                    selector: '[kendoAIPromptOutputCard]',
                    template: `
        <div class="k-card-header">
            <div
                class="k-card-title"
                [attr.id]="titleId">{{outputTitle}}
            </div>
            <div class="k-card-subtitle">{{promptOutput.prompt}}</div>
        </div>
        <div class="k-card-body">
            <p>{{promptOutput.output}}</p>
        </div>
        <div class="k-actions k-actions-start k-actions-horizontal k-card-actions">
            <button kendoButton
                fillMode="flat"
                themeColor="primary"
                rounded="full"
                icon="copy"
                [svgIcon]="copyIcon"
                (click)="handleCopy()"
            >{{messageFor('copyOutput')}}</button>
            <button kendoButton
                fillMode="flat"
                rounded="full"
                icon="arrow-rotate-cw"
                [svgIcon]="retryIcon"
                (click)="handleRetry()"
            >{{messageFor('retryGeneration')}}</button>
            <ng-container *ngIf="showRating">
                <span class="k-spacer"></span>
                <button kendoButton
                    fillMode="flat"
                    icon="thumb-up-outline"
                    [svgIcon]="positiveRatingIcon"
                    (click)="handleRating('positive')">
                </button>
                <button kendoButton
                    fillMode="flat"
                    icon="thumb-down-outline"
                    [svgIcon]="negativeRatingIcon"
                    (click)="handleRating('negative')">
                </button>
            </ng-container>
        </div>
    `,
                    standalone: true,
                    imports: [ButtonComponent, NgIf]
                }]
        }], ctorParameters: function () { return [{ type: i1$1.LocalizationService }, { type: AIPromptService }]; }, propDecorators: { hostClass: [{
                type: HostBinding,
                args: ['class.k-card']
            }], listItemRole: [{
                type: HostBinding,
                args: ['attr.role']
            }], tabIndex: [{
                type: HostBinding,
                args: ['attr.tabindex']
            }], ariaDescribedBy: [{
                type: HostBinding,
                args: ['attr.aria-describedby']
            }], ariaKeyShortcuts: [{
                type: HostBinding,
                args: ['attr.aria-keyshortcuts']
            }], promptOutput: [{
                type: Input
            }] } });

/**
 * Represents the component that renders the **Output** view of the AIPrompt.
 *
 * @example
 * ```html
 * <kendo-aiprompt-output-view
 *      buttonText="My output view">
 * </kendo-aiprompt-output-view>
 * ```
 */
class OutputViewComponent extends BaseView {
    service;
    constructor(localization, service) {
        super('output', localization);
        this.service = service;
    }
    /**
     * @hidden
     */
    get promptOutputs() {
        return this.service.promptOutputs;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: OutputViewComponent, deps: [{ token: i1$1.LocalizationService }, { token: AIPromptService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: OutputViewComponent, isStandalone: true, selector: "kendo-aiprompt-output-view", providers: [{
                provide: BaseView,
                useExisting: forwardRef(() => OutputViewComponent)
            }], usesInheritance: true, ngImport: i0, template: `
        <ng-template #content>
            <div
                class="k-card-list"
                role="list">
                <div *ngFor="let output of promptOutputs"
                    kendoAIPromptOutputCard
                    [promptOutput]="output">
                </div>
            </div>
        </ng-template>
    `, isInline: true, dependencies: [{ kind: "directive", type: NgFor, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "component", type: AIPromptOutputCardComponent, selector: "[kendoAIPromptOutputCard]", inputs: ["promptOutput"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: OutputViewComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'kendo-aiprompt-output-view',
                    providers: [{
                            provide: BaseView,
                            useExisting: forwardRef(() => OutputViewComponent)
                        }],
                    template: `
        <ng-template #content>
            <div
                class="k-card-list"
                role="list">
                <div *ngFor="let output of promptOutputs"
                    kendoAIPromptOutputCard
                    [promptOutput]="output">
                </div>
            </div>
        </ng-template>
    `,
                    standalone: true,
                    imports: [NgFor, AIPromptOutputCardComponent]
                }]
        }], ctorParameters: function () { return [{ type: i1$1.LocalizationService }, { type: AIPromptService }]; } });

/**
 * Represents the component that renders the **Prompt** view of the AIPrompt.
 *
 * @example
 * ```html
 * <kendo-aiprompt-prompt-view
 *      buttonText="My prompt view">
 * </kendo-aiprompt-prompt-view>
 * ```
 */
class PromptViewComponent extends BaseView {
    service;
    constructor(localization, service) {
        super('prompt', localization);
        this.service = service;
    }
    /**
     * @hidden
     */
    get suggestionsIcons() {
        return this.showSuggestions ?
            { font: 'chevron-up', svg: chevronUpIcon } :
            { font: 'chevron-down', svg: chevronDownIcon };
    }
    /**
     * @hidden
     */
    showSuggestions = true;
    /**
     * @hidden
     */
    contentId = `k-prompt-suggestions-${guid()}`;
    /**
     * @hidden
     */
    get promptSuggestions() {
        return this.service.promptSuggestions;
    }
    /**
     *
     * @hidden
     */
    set textAreaValue(value) {
        this.service.promptValue = value;
    }
    get textAreaValue() {
        return this.service.promptValue;
    }
    /**
     * @hidden
     */
    suggestionClick(suggestion) {
        this.textAreaValue = this.service.promptValue = suggestion;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: PromptViewComponent, deps: [{ token: i1$1.LocalizationService }, { token: AIPromptService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: PromptViewComponent, isStandalone: true, selector: "kendo-aiprompt-prompt-view", providers: [
            {
                provide: BaseView,
                useExisting: forwardRef(() => PromptViewComponent)
            }
        ], usesInheritance: true, ngImport: i0, template: `
        <ng-template #content>
            <kendo-textarea
                [placeholder]="messageFor('promptPlaceholder')"
                [rows]="1"
                [(value)]="textAreaValue">
            </kendo-textarea>
            <div *ngIf="promptSuggestions"
                class="k-prompt-expander">
                <button kendoButton
                    [attr.aria-controls]="contentId"
                    [attr.aria-expanded]="showSuggestions"
                    fillMode="flat"
                    [icon]="suggestionsIcons.font"
                    [svgIcon]="suggestionsIcons.svg"
                    type="button"
                    (click)="showSuggestions = !showSuggestions">
                    {{messageFor('promptSuggestions')}}
                </button>
                <div *ngIf="showSuggestions"
                    class="k-prompt-expander-content"
                    role="list"
                    [attr.id]="contentId">
                    <div *ngFor="let suggestion of promptSuggestions"
                        class="k-prompt-suggestion"
                        role="listitem"
                        (click)="suggestionClick(suggestion)">
                        {{suggestion}}
                    </div>
                </div>
            </div>
        </ng-template>
    `, isInline: true, dependencies: [{ kind: "component", type: TextAreaComponent, selector: "kendo-textarea", inputs: ["focusableId", "flow", "inputAttributes", "adornmentsOrientation", "rows", "cols", "maxlength", "tabindex", "tabIndex", "resizable", "size", "rounded", "fillMode", "showPrefixSeparator", "showSuffixSeparator"], outputs: ["focus", "blur", "valueChange"], exportAs: ["kendoTextArea"] }, { kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: ButtonComponent, selector: "button[kendoButton]", inputs: ["arrowIcon", "toggleable", "togglable", "selected", "tabIndex", "imageUrl", "iconClass", "icon", "disabled", "size", "rounded", "fillMode", "themeColor", "svgIcon", "primary", "look"], outputs: ["selectedChange", "click"], exportAs: ["kendoButton"] }, { kind: "directive", type: NgFor, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: PromptViewComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'kendo-aiprompt-prompt-view',
                    providers: [
                        {
                            provide: BaseView,
                            useExisting: forwardRef(() => PromptViewComponent)
                        }
                    ],
                    template: `
        <ng-template #content>
            <kendo-textarea
                [placeholder]="messageFor('promptPlaceholder')"
                [rows]="1"
                [(value)]="textAreaValue">
            </kendo-textarea>
            <div *ngIf="promptSuggestions"
                class="k-prompt-expander">
                <button kendoButton
                    [attr.aria-controls]="contentId"
                    [attr.aria-expanded]="showSuggestions"
                    fillMode="flat"
                    [icon]="suggestionsIcons.font"
                    [svgIcon]="suggestionsIcons.svg"
                    type="button"
                    (click)="showSuggestions = !showSuggestions">
                    {{messageFor('promptSuggestions')}}
                </button>
                <div *ngIf="showSuggestions"
                    class="k-prompt-expander-content"
                    role="list"
                    [attr.id]="contentId">
                    <div *ngFor="let suggestion of promptSuggestions"
                        class="k-prompt-suggestion"
                        role="listitem"
                        (click)="suggestionClick(suggestion)">
                        {{suggestion}}
                    </div>
                </div>
            </div>
        </ng-template>
    `,
                    standalone: true,
                    imports: [TextAreaComponent, NgIf, ButtonComponent, NgFor]
                }]
        }], ctorParameters: function () { return [{ type: i1$1.LocalizationService }, { type: AIPromptService }]; } });

// eslint-disable no-forward-ref
/**
 * Represents the custom messages component of the Chat.
 *
 * Use this component to override default messages for the Chat
 * ([see example](slug:globalization_chat#custom-messages)).
 *
 * @example
 * ```html
 * <kendo-chat-messages
 *   send="Send Message"
 *   messagePlaceholder="Type here...">
 * </kendo-chat-messages>
 * ```
 */
class CustomMessagesComponent extends Messages$1 {
    service;
    constructor(service) {
        super();
        this.service = service;
    }
    get override() {
        return true;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CustomMessagesComponent, deps: [{ token: i1$1.LocalizationService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: CustomMessagesComponent, isStandalone: true, selector: "kendo-chat-messages", providers: [
            {
                provide: Messages$1,
                useExisting: forwardRef(() => CustomMessagesComponent)
            }
        ], usesInheritance: true, ngImport: i0, template: ``, isInline: true });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CustomMessagesComponent, decorators: [{
            type: Component,
            args: [{
                    providers: [
                        {
                            provide: Messages$1,
                            useExisting: forwardRef(() => CustomMessagesComponent)
                        }
                    ],
                    selector: 'kendo-chat-messages',
                    template: ``,
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1$1.LocalizationService }]; } });

/**
 * Represents a Hero Card component ([see example](slug:dialogflow_chat)).
 * Hero cards host a single large image and action buttons with text content.
 *
 * @example
 * ```html
 * <kendo-chat-hero-card
 *   title="Card Title"
 *   subtitle="Card Subtitle"
 *   [actions]="actions">
 * </kendo-chat-hero-card>
 * ```
 */
class HeroCardComponent {
    /**
     * Sets the URL of the hero card image.
     */
    imageUrl;
    /**
     * Sets the title of the hero card.
     */
    title;
    /**
     * Sets the subtitle of the hero card.
     */
    subtitle;
    /**
     * Sets the array of quick actions for this hero card.
     */
    actions;
    cssClass = true;
    /**
     * Fires when the user clicks a button.
     */
    executeAction = new EventEmitter();
    /**
     * Emits the `executeAction` event when the user clicks an action button.
     */
    onClick(action) {
        this.executeAction.next(action);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: HeroCardComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: HeroCardComponent, isStandalone: true, selector: "kendo-chat-hero-card", inputs: { imageUrl: "imageUrl", title: "title", subtitle: "subtitle", actions: "actions" }, outputs: { executeAction: "executeAction" }, host: { properties: { "class.k-card": "this.cssClass" } }, ngImport: i0, template: `
        <img class="k-card-image" [src]="imageUrl" *ngIf="imageUrl" />
        <div class="k-card-body">
        <h5 class="k-card-title" *ngIf="title">
            {{ title }}
        </h5>
        <h6 class="k-card-subtitle" *ngIf="subtitle">
            {{ subtitle }}
        </h6>
        </div>
        <div class="k-card-actions k-card-actions-vertical">
        <span class="k-card-action"
                *ngFor="let act of actions"
        >
            <button
                kendoButton fillMode="flat"
                (click)="onClick(act)"
            >
                    {{ act.title }}
            </button>
        </span>
        </div>
    `, isInline: true, dependencies: [{ kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: NgFor, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "component", type: ButtonComponent, selector: "button[kendoButton]", inputs: ["arrowIcon", "toggleable", "togglable", "selected", "tabIndex", "imageUrl", "iconClass", "icon", "disabled", "size", "rounded", "fillMode", "themeColor", "svgIcon", "primary", "look"], outputs: ["selectedChange", "click"], exportAs: ["kendoButton"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: HeroCardComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'kendo-chat-hero-card',
                    template: `
        <img class="k-card-image" [src]="imageUrl" *ngIf="imageUrl" />
        <div class="k-card-body">
        <h5 class="k-card-title" *ngIf="title">
            {{ title }}
        </h5>
        <h6 class="k-card-subtitle" *ngIf="subtitle">
            {{ subtitle }}
        </h6>
        </div>
        <div class="k-card-actions k-card-actions-vertical">
        <span class="k-card-action"
                *ngFor="let act of actions"
        >
            <button
                kendoButton fillMode="flat"
                (click)="onClick(act)"
            >
                    {{ act.title }}
            </button>
        </span>
        </div>
    `,
                    standalone: true,
                    imports: [NgIf, NgFor, ButtonComponent]
                }]
        }], propDecorators: { imageUrl: [{
                type: Input
            }], title: [{
                type: Input
            }], subtitle: [{
                type: Input
            }], actions: [{
                type: Input
            }], cssClass: [{
                type: HostBinding,
                args: ['class.k-card']
            }], executeAction: [{
                type: Output
            }] } });

/**
 * Utility array that contains all AIPrompt related components and directives.
 *
 * @example
 * ```ts
 * import { Component } from '@angular/core';
 * import { KENDO_AIPROMPT } from '@progress/kendo-angular-conversational-ui';
 *
 * @Component({
 *   standalone: true,
 *   imports: [KENDO_AIPROMPT],
 *   selector: 'my-app',
 *   template: `<kendo-aiprompt></kendo-aiprompt>`
 * })
 * export class AppComponent {}
 * ```
 */
const KENDO_AIPROMPT = [
    AIPromptComponent,
    PromptViewComponent,
    OutputViewComponent,
    CommandViewComponent,
    CustomViewComponent,
    AIPromptCustomMessagesComponent,
    AIPromptToolbarActionsDirective,
    AIPromptToolbarFocusableDirective
];
/**
 * Utility array that contains all Chat related components and directives.
 *
 * @example
 * ```ts
 * import { Component } from '@angular/core';
 * import { KENDO_CHAT } from '@progress/kendo-angular-conversational-ui';
 *
 * @Component({
 *   standalone: true,
 *   imports: [KENDO_CHAT],
 *   selector: 'my-app',
 *   template: `<kendo-chat></kendo-chat>`
 * })
 * export class AppComponent {}
 * ```
 */
const KENDO_CHAT = [
    ChatComponent,
    CustomMessagesComponent,
    AttachmentTemplateDirective,
    MessageTemplateDirective,
    HeroCardComponent,
    ChatMessageBoxTemplateDirective
];
/**
 * Utility array that contains all `@progress/kendo-angular-conversational-ui` related components and directives.
 *
 * @example
 * ```ts
 * import { Component } from '@angular/core';
 * import { KENDO_CONVERSATIONALUI } from '@progress/kendo-angular-conversational-ui';
 *
 * @Component({
 *   standalone: true,
 *   imports: [KENDO_CONVERSATIONALUI],
 *   selector: 'my-app',
 *   template: `
 *     <kendo-aiprompt></kendo-aiprompt>
 *     <kendo-chat></kendo-chat>
 *   `
 * })
 * export class AppComponent {}
 * ```
 */
const KENDO_CONVERSATIONALUI = [
    ...KENDO_AIPROMPT,
    ...KENDO_CHAT
];

// IMPORTANT: NgModule export kept for backwards compatibility
/**
 * Represents the [`NgModule`](link:site.data.urls.angular['ngmodules']) for the AIPrompt component.
 *
 * @example
 * ```ts
 * import { NgModule } from '@angular/core';
 * import { BrowserModule } from '@angular/platform-browser';
 * import { AIPromptModule } from '@progress/kendo-angular-conversational-ui';
 * import { AppComponent } from './app.component';
 *
 * @NgModule({
 *   imports: [BrowserModule, AIPromptModule],
 *   declarations: [AppComponent],
 *   bootstrap: [AppComponent]
 * })
 * export class AppModule {}
 * ```
 */
class AIPromptModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AIPromptModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.2.12", ngImport: i0, type: AIPromptModule, imports: [AIPromptComponent, PromptViewComponent, OutputViewComponent, CommandViewComponent, CustomViewComponent, AIPromptCustomMessagesComponent, AIPromptToolbarActionsDirective, AIPromptToolbarFocusableDirective], exports: [AIPromptComponent, PromptViewComponent, OutputViewComponent, CommandViewComponent, CustomViewComponent, AIPromptCustomMessagesComponent, AIPromptToolbarActionsDirective, AIPromptToolbarFocusableDirective] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AIPromptModule, providers: [IconsService, PopupService, ResizeBatchService, DialogContainerService, DialogService, WindowService, WindowContainerService], imports: [AIPromptComponent, PromptViewComponent, OutputViewComponent, CommandViewComponent] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AIPromptModule, decorators: [{
            type: NgModule,
            args: [{
                    exports: [...KENDO_AIPROMPT],
                    imports: [...KENDO_AIPROMPT],
                    providers: [IconsService, PopupService, ResizeBatchService, DialogContainerService, DialogService, WindowService, WindowContainerService]
                }]
        }] });

// IMPORTANT: NgModule export kept for backwards compatibility
/**
 * Represents the [`NgModule`](link:site.data.urls.angular['ngmodules']) for the Chat component.
 *
 * @example
 * ```ts-no-run
 * import { NgModule } from '@angular/core';
 * import { Component } from '@angular/core';
 * import { BrowserModule } from '@angular/platform-browser';
 *
 * import { ChatModule } from '@progress/kendo-angular-conversational-ui';
 * import { AppComponent } from './app.component';
 *
 * _@NgModule({
 *   imports: [BrowserModule, ChatModule],
 *   declarations: [AppComponent],
 *   bootstrap: [AppComponent]
 * })
 *
 * export class AppModule { }
 * ```
 */
class ChatModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ChatModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.2.12", ngImport: i0, type: ChatModule, imports: [ChatComponent, CustomMessagesComponent, AttachmentTemplateDirective, MessageTemplateDirective, HeroCardComponent, ChatMessageBoxTemplateDirective], exports: [ChatComponent, CustomMessagesComponent, AttachmentTemplateDirective, MessageTemplateDirective, HeroCardComponent, ChatMessageBoxTemplateDirective] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ChatModule, providers: [IconsService, ResizeBatchService], imports: [ChatComponent, HeroCardComponent] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ChatModule, decorators: [{
            type: NgModule,
            args: [{
                    exports: [...KENDO_CHAT],
                    imports: [...KENDO_CHAT],
                    providers: [IconsService, ResizeBatchService]
                }]
        }] });

// IMPORTANT: NgModule export kept for backwards compatibility
/**
 * Represents the [`NgModule`](link:site.data.urls.angular['ngmodules']) for the Conversational UI components.
 *
 * @example
 * ```ts
 * import { NgModule } from '@angular/core';
 * import { BrowserModule } from '@angular/platform-browser';
 * import { ConversationalUIModule } from '@progress/kendo-angular-conversational-ui';
 * import { AppComponent } from './app.component';
 *
 * @NgModule({
 *   declarations: [AppComponent],
 *   imports: [BrowserModule, ConversationalUIModule],
 *   bootstrap: [AppComponent]
 * })
 * export class AppModule {}
 * ```
 */
class ConversationalUIModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ConversationalUIModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.2.12", ngImport: i0, type: ConversationalUIModule, imports: [AIPromptComponent, PromptViewComponent, OutputViewComponent, CommandViewComponent, CustomViewComponent, AIPromptCustomMessagesComponent, AIPromptToolbarActionsDirective, AIPromptToolbarFocusableDirective, ChatComponent, CustomMessagesComponent, AttachmentTemplateDirective, MessageTemplateDirective, HeroCardComponent, ChatMessageBoxTemplateDirective], exports: [AIPromptComponent, PromptViewComponent, OutputViewComponent, CommandViewComponent, CustomViewComponent, AIPromptCustomMessagesComponent, AIPromptToolbarActionsDirective, AIPromptToolbarFocusableDirective, ChatComponent, CustomMessagesComponent, AttachmentTemplateDirective, MessageTemplateDirective, HeroCardComponent, ChatMessageBoxTemplateDirective] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ConversationalUIModule, providers: [IconsService, PopupService, ResizeBatchService, DialogContainerService, DialogService, WindowService, WindowContainerService], imports: [AIPromptComponent, PromptViewComponent, OutputViewComponent, CommandViewComponent, ChatComponent, HeroCardComponent] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ConversationalUIModule, decorators: [{
            type: NgModule,
            args: [{
                    exports: [...KENDO_CONVERSATIONALUI],
                    imports: [...KENDO_CONVERSATIONALUI],
                    providers: [IconsService, PopupService, ResizeBatchService, DialogContainerService, DialogService, WindowService, WindowContainerService]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { AIPromptComponent, AIPromptCustomMessagesComponent, AIPromptModule, AIPromptToolbarActionsDirective, AIPromptToolbarFocusableDirective, AttachmentTemplateDirective, ChatComponent, ChatMessageBoxTemplateDirective, ChatModule, CommandViewComponent, ConversationalUIModule, CustomMessagesComponent, CustomViewComponent, ExecuteActionEvent, HeroCardComponent, KENDO_AIPROMPT, KENDO_CHAT, KENDO_CONVERSATIONALUI, MessageTemplateDirective, OutputViewComponent, PromptViewComponent, SendMessageEvent };

